<?php

namespace backend\modules\career\controllers;

use backend\modules\career\models\UserVacancy;
use common\models\User;
use Yii;
use yeesoft\controllers\admin\BaseController;
use yii\data\ActiveDataProvider;

/**
 * DefaultController implements the CRUD actions for backend\modules\career\models\Vacancy model.
 */
class DefaultController extends BaseController
{
    public $modelClass = 'backend\modules\career\models\Vacancy';
    public $modelSearchClass = 'backend\modules\career\models\search\VacancySearch';

    protected function getRedirectPage($action, $model = null)
    {
        switch ($action) {
            case 'update':
                return ['update', 'id' => $model->id];
                break;
            case 'create':
                return ['update', 'id' => $model->id];
                break;
            default:
                return parent::getRedirectPage($action, $model);
        }
    }

    public function actionAppliedUsers($id)
    {

        $model = $this->findModel($id);

        $params = Yii::$app->request->get();
        $params['UserVacancy']['vacancy_id'] = $id;

        $searchModel = new UserVacancy();

        $userAppliedDataProvider = $searchModel->search($params);
        return $this->renderIsAjax('applied-users', [
            'model' => $model,
            'searchModel' => $searchModel,
            'userAppliedDataProvider' => $userAppliedDataProvider
        ]);
    }
    public function actionViewUserProfile($v_id, $u_id){
        $model = $this->findModel($v_id);
        $user = User::findOne($u_id);

        $linkModel = UserVacancy::findOne(['user_id' => $user->id, 'vacancy_id' => $v_id]);
        if($linkModel){
            $linkModel->viewed = 1;
            $linkModel->save(false);
        }
        return $this->redirect(['/user/default/view', 'id' => $user->id]);

    }
    public function actionApproveUser($v_id, $u_id)
    {

        $model = $this->findModel($v_id);
        $user = User::findOne($u_id);

        $linkModel = UserVacancy::findOne(['user_id' => $user->id, 'vacancy_id' => $v_id]);
        if($linkModel){
            $linkModel->status = 'APPROVED';
            $linkModel->save(false);

            //Send Email
            Yii::$app->mailer->compose()
                ->setTo($user->email)
                ->setFrom([Yii::$app->params['fromEmail'] => Yii::$app->params['fromName']])
                ->setSubject('Approved - ' . $model->title)
                ->setTextBody('')
                ->send();
        }

        Yii::$app->session->setFlash('crudMessage', Yii::t('site', 'User Approved.'));


        return $this->redirect(Yii::$app->request->referrer);
    }
    public function actionRejectUser($v_id, $u_id)
    {

        $model = $this->findModel($v_id);
        $user = User::findOne($u_id);

        $linkModel = UserVacancy::findOne(['user_id' => $user->id, 'vacancy_id' => $v_id]);
        if($linkModel){
            $linkModel->status = 'REJECTED';
            $linkModel->save(false);

            //Send Email
            Yii::$app->mailer->compose()
                ->setTo($user->email)
                ->setFrom([Yii::$app->params['fromEmail'] => Yii::$app->params['fromName']])
                ->setSubject('Rejected - ' . $model->title)
                ->setTextBody('')
                ->send();
        }

        Yii::$app->session->setFlash('crudMessage', Yii::t('site', 'User Rejected.'));


        return $this->redirect(Yii::$app->request->referrer);
    }
    public function actionCompareUser()
    {

        $params = explode('|', Yii::$app->request->get('users'));

        $user1 = UserVacancy::findOne($params[0])->user;
        $user2 = UserVacancy::findOne($params[1])->user;

        $params['user1'] = $user1;
        $params['personalInformation1'] = $user1->personalInformation;
        $params['educations1'] = $user1->educations;
        $params['certificates1'] = $user1->certificates;
        $params['userFileDataProvider1'] = $user1->getFilesDataProvider();
        $params['employeeHistories1'] = $user1->employeeHistories;

//        $user1 = $this->renderFile( Yii::getAlias('@app') . '/modules/yeesoft/yii2-yee-user/views/default/view.php', $params);


        $params['user2'] = $user2;
        $params['personalInformation2'] = $user2->personalInformation;
        $params['educations2'] = $user2->educations;
        $params['certificates2'] = $user2->certificates;
        $params['userFileDataProvider2'] = $user2->getFilesDataProvider();
        $params['employeeHistories2'] = $user2->employeeHistories;

//        $user2 = $this->renderFile( Yii::getAlias('@app') . '/modules/yeesoft/yii2-yee-user/views/default/view.php', $params);

//        return $this->render('compare-user', ['user1' => $user1, 'user2' => $user2]);
        return $this->render('compare-user', $params);

    }


    public function actionSetInterview()
    {
        $params = Yii::$app->request->post('DynamicModel');

        $vacancyModel = $this->findModel($params['v_id']);
        $user = User::findOne($params['u_id']);


        $userVacancyModel = UserVacancy::findOne(['vacancy_id' => $vacancyModel->id, 'user_id' => $user->id]);
        /* @var $userVacancyModel UserVacancy */
        $userVacancyModel->updateInterView($params['interview_date']);

        Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been updated.'));
        return $this->redirect(Yii::$app->request->referrer);


    }
}