<?php

namespace backend\modules\career\controllers;

use backend\modules\bms\models\Bms;
use backend\modules\bms\models\search\BmsSearch;
use backend\modules\career\models\RecruitmentGuidanceBms;
use Yii;
use yeesoft\controllers\admin\BaseController;
use yii\filters\VerbFilter;
use yii\helpers\ArrayHelper;

/**
 * GuidanceController implements the CRUD actions for backend\modules\career\models\RecruitmentGuidance model.
 */
class GuidanceController extends BaseController
{
    public $modelClass = 'backend\modules\career\models\RecruitmentGuidance';
    public $modelSearchClass = 'backend\modules\career\models\search\RecruitmentGuidanceSearch';


    public function behaviors()
    {
        return ArrayHelper::merge(parent::behaviors(), [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['post'],
                ],
            ],
        ]);
    }

    protected function getRedirectPage($action, $model = null)
    {
        switch ($action) {
            case 'update':
                return ['update', 'id' => $model->id];
                break;
            case 'create':
                return ['update', 'id' => $model->id];
                break;
            default:
                return parent::getRedirectPage($action, $model);
        }
    }


    /**
     * Displays a single model.
     *
     * @param integer $id
     *
     * @return mixed
     */
    public function actionView($id)
    {

        $model = $this->findModel($id);

        $searchModel = new BmsSearch();

        $params['BmsSearch'] = ['category' => 'GuidanceFeature', 'guidance_id' => $id];

        $bmsDataProvider = $searchModel->search($params);

        $footerBms = Bms::find()->multilingual()->innerJoinWith('guidanceBms')
            ->where(['guidance_id' => $id, 'category' => 'RecruitmentGuidance'])->one();

        if (!$footerBms) {
            $footerBms = new Bms();
        }


        if ($footerBms->load(Yii::$app->request->post()) && $footerBms->save()) {


            $obj = RecruitmentGuidanceBms::findOne(['guidance_id' => $model->id, 'bms_id' => $footerBms->id]);
            $obj = $obj ?: New RecruitmentGuidanceBms();
            $obj->guidance_id = $model->id;
            $obj->bms_id = $footerBms->id;
            $obj->save(false);

            Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been created.'));
            return $this->redirect(['view', 'id' => $model->id]);
        }


        return $this->renderIsAjax($this->viewView, [
            'model' => $model, 'bmsDataProvider' => $bmsDataProvider, 'footerBms' => $footerBms
        ]);
    }


    /**
     * Updates an existing model.
     * If update is successful, the browser will be redirected to the 'view' page.
     *
     * @param integer $id
     *
     * @return mixed
     */
    public function actionCreateFeature($id)
    {
        /* @var $model \yeesoft\db\ActiveRecord */
        $model = parent::findModel($id);
        $bmsModel = new Bms();

        if ($bmsModel->load(Yii::$app->request->post()) && $bmsModel->save()) {

            $obj = New RecruitmentGuidanceBms();
            $obj->guidance_id = $model->id;
            $obj->bms_id = $bmsModel->id;
            $obj->save(false);

            Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been created.'));
            return $this->redirect(['view', 'id' => $model->id]);
        }

        return $this->renderIsAjax('create-feature', ['model' => $model, 'bmsModel' => $bmsModel]);
    }

    public function actionUpdateFeature($id, $guidance_id = null)
    {
        /* @var $model \yeesoft\db\ActiveRecord */
        $bmsModel = Bms::find()->andWhere(['id' => $id])->multilingual()->one();


        if ($bmsModel->load(Yii::$app->request->post()) && $bmsModel->save()) {

            Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been updated.'));
            return $this->redirect(['view', 'id' => $_POST['guidance_id']]);
        }

        return $this->renderIsAjax('update-feature', ['bmsModel' => $bmsModel, 'guidance_id' => $guidance_id]);
    }

    public function actionDeleteFeature($id, $guidance_id = null)
    {
        /* @var $model \yeesoft\db\ActiveRecord */

        if (Bms::deleteAll(['id' => $id])){
            Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been deleted.'));
        }

        return $this->redirect(['view', 'id' => $guidance_id]);
    }
}