<?php

namespace backend\modules\doctor_questionnaire\models;

use bedezign\yii2\audit\AuditTrailBehavior;
use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "doctor_questionnaire_item".
 *
 * @property int $id
 * @property int $parent_id
 * @property string $slug
 * @property int $group_id Dropdown Menu - QuestionnaireGroups
 * @property int $status 0-pending,1-published
 * @property int $published_at
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property int $revision
 * @property string $view
 * @property string $layout
 *
 * @property DoctorQuestionnaire $parent
 * @property UserDoctorQuestionnaireAnswer[] $userDoctorQuestionnaireAnswers
 */
class DoctorQuestionnaireItem extends ActiveRecord
{

    //Use it on Admin Form
    public $q_en, $q_ar, $number_of_cases;

    //Use it on User Form
    public $questions;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'doctor_questionnaire_item';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['parent_id', 'group_id', 'status', 'published_at', 'created_at', 'updated_at', 'created_by', 'updated_by', 'revision'], 'integer'],
            [['title'], 'required'],
            [['questions'], 'required', 'on' => 'JobApply'],
            [['slug', 'view', 'layout'], 'string', 'max' => 255],
            [['q_en', 'q_ar'], 'string', 'max' => 255],
            [['q_en', 'q_ar'], 'required'],
            [['number_of_cases'], 'integer'],
            [['parent_id'], 'exist', 'skipOnError' => true, 'targetClass' => DoctorQuestionnaire::className(), 'targetAttribute' => ['parent_id' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            AuditTrailBehavior::className(),
            TimestampBehavior::className(),
            BlameableBehavior::className(),
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'attribute' => 'title',
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'parent_id',
                'tableName' => "{{%doctor_questionnaire_item_lang}}",
                'attributes' => [
                    'title'
                ]
            ],
        ];
    }
    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'parent_id' => Yii::t('site', 'Parent ID'),
            'slug' => Yii::t('site', 'Slug'),
            'group_id' => Yii::t('site', 'Group ID'),
            'status' => Yii::t('site', 'Status'),
            'published_at' => Yii::t('site', 'Published At'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
            'created_by' => Yii::t('site', 'Created By'),
            'updated_by' => Yii::t('site', 'Updated By'),
            'revision' => Yii::t('site', 'Revision'),
            'view' => Yii::t('site', 'View'),
            'layout' => Yii::t('site', 'Layout'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParent()
    {
        return $this->hasOne(DoctorQuestionnaire::className(), ['id' => 'parent_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getUserDoctorQuestionnaireAnswers()
    {
        return $this->hasMany(UserDoctorQuestionnaireAnswer::className(), ['generals_question_id' => 'id']);
    }

    /**
     * {@inheritdoc}
     * @return DoctorQuestionnaireItemQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new DoctorQuestionnaireItemQuery(get_called_class());
    }
}
