<?php

namespace backend\modules\places\controllers;

use backend\modules\places\models\ClassificationForm;
use backend\modules\places\models\Filter;
use backend\modules\places\models\Group;
use backend\modules\places\models\PlaceImages;
use backend\modules\places\models\PlaceRating;
use backend\modules\places\models\Places;
use backend\modules\places\models\search\PlacesModelSearch;
use Yii;
use yeesoft\controllers\admin\BaseController;
use yii\filters\VerbFilter;
use yii\helpers\ArrayHelper;
use yii\helpers\Json;
use yii\web\MethodNotAllowedHttpException;
use yii\web\Response;

/**
 * DefaultController implements the CRUD actions for backend\modules\places\models\Places model.
 */
class DefaultController extends BaseController
{
    public $modelClass = 'backend\modules\places\models\Places';
    public $modelSearchClass = 'backend\modules\places\models\search\PlacesModelSearch';

    public function behaviors()
    {
        return ArrayHelper::merge(parent::behaviors(), [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['post'],
                ],
            ],
        ]);
    }

    protected function getRedirectPage($action, $model = null)
    {
        switch ($action) {
            case 'update':
                return ['update', 'id' => $model->id];
                break;
            case 'create':
                return ['update', 'id' => $model->id];
                break;
            default:
                return parent::getRedirectPage($action, $model);
        }
    }


    /**
     * Lists all models.
     * @return mixed
     */
    public function actionAddedByUser()
    {
        $searchModel = new PlacesModelSearch();

        if ($searchModel) {
            $params = Yii::$app->request->getQueryParams();

            $dataProvider = $searchModel->search($params);
            $dataProvider->query->andWhere(['<>', 'created_by', 1]);
//            echo $dataProvider->query->createCommand()->rawSql;
        }

        return $this->renderIsAjax($this->indexView, compact('dataProvider', 'searchModel'));
    }


    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        /* @var $model \yeesoft\db\ActiveRecord */
        $model = new $this->modelClass;

        $classifications = [];
        foreach ($model->filters as $filter) {
            $group = $filter->filter->group;

            //Main Filter
            if (!$group) continue;

            $subsector = $group->subsector;
            $tmp = new ClassificationForm();
            $tmp->load(['ClassificationForm' => ['subsector' => $subsector->id, 'group' => $group->id, 'filter' => $filter->filter_id]], 'ClassificationForm');
            $classifications[] = $tmp;
        }

        $model->classifications = count($classifications) ? $classifications : [new ClassificationForm()];

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been created.'));
            return $this->redirect($this->getRedirectPage('create', $model));
        }

        return $this->renderIsAjax($this->createView, compact('model'));
    }

    /**
     * Updates an existing model.
     * If update is successful, the browser will be redirected to the 'view' page.
     *
     * @param integer $id
     *
     * @return mixed
     */
    public function actionUpdate($id)
    {
        /* @var $model \yeesoft\db\ActiveRecord */
        $model = parent::findModel($id);


        $classifications = [];
        foreach ($model->filters as $filter) {

            $group = $filter->filter->group;
            //Main Filter
            if (!$group) continue;

            $subsector = $group->subsector;
            $tmp = new ClassificationForm();
            $tmp->load(['ClassificationForm' => ['subsector' => $subsector->id, 'group' => $group->id, 'filter' => $filter->filter_id]], 'ClassificationForm');
            $classifications[] = $tmp;
        }

        $model->classifications = count($classifications) ? $classifications : [new ClassificationForm()];


        if ($model->load(Yii::$app->request->post()) AND $model->save()) {
            Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been updated.'));
            return $this->redirect($this->getRedirectPage('update', $model));
        }

        return $this->renderIsAjax($this->updateView, compact('model'));
    }

    public function actionDepGroup()
    {
        $lng = Yii::$app->language;
        $out = array();
        //$out[] = ['id' => ' ', 'name' => 'Select ....'];
        if (isset($_POST['depdrop_parents'])) {
            $term_id = end($_POST['depdrop_parents']);
            $list = Group::find()
                ->andWhere(["subsector_id" => $term_id])->all();
            if ($term_id != null && count($list) > 0) {
                $selected = '';
                foreach ($list as $i => $item) {
                    $out[] = ['id' => $item->id, 'name' => $item["name_{$lng}"]];
                }
                // Shows how you can preselect a value
                echo Json::encode(['output' => $out, 'selected' => $selected]);
                return;
            }
        }
        echo Json::encode(['output' => [], 'selected' => '']);
    }

    public function actionDepFilter()
    {
        $lng = Yii::$app->language;
        $out = array();
        //$out[] = ['id' => ' ', 'name' => 'Select ....'];
        if (isset($_POST['depdrop_parents'])) {
            $term_id = end($_POST['depdrop_parents']);
            $list = Filter::find()
                ->andWhere(["group_id" => $term_id])->all();
            if ($term_id != null && count($list) > 0) {
                $selected = '';
                foreach ($list as $i => $item) {
                    $out[] = ['id' => $item->id, 'name' => $item["name_{$lng}"]];
                }
                // Shows how you can preselect a value
                echo Json::encode(['output' => $out, 'selected' => $selected]);
                return;
            }
        }
        echo Json::encode(['output' => [], 'selected' => '']);
    }

    public function actionClearRating()
    {
        if (Yii::$app->request->getIsAjax()) {
            Yii::$app->response->format = Response::FORMAT_JSON;
            if (null === $modelId = (int)Yii::$app->request->post('modelId')) {
                return ['content' => Yii::t('vote', 'modelId has not been sent')];
            }

            $value = (int)Yii::$app->request->post('rate');
            $type = Yii::$app->request->post('type');

            $userId = Yii::$app->user->getId();
            if ($userId === null && !PlaceRating::getIsAllowGuests()) {
                return ['content' => Yii::t('vote', 'Guests are not allowed to vote')];
            }
            if (!$userIp = PlaceRating::compressIp(Yii::$app->request->getUserIP())) {
                return ['content' => Yii::t('vote', 'The user is not recognized')];
            }
            if (!is_int($modelId)) {
                return ['content' => Yii::t('vote', 'The model is not registered')];
            }

            PlaceRating::deleteAll(['model_id' => $modelId, 'user_id' => $userId]);

            return ['content' => Yii::t('vote', 'Thanks for your opinion'), 'success' => true, 'rating' => 0];

        } else {
            throw new MethodNotAllowedHttpException(Yii::t('vote', 'Forbidden method'), 405);
        }
    }

    public function actionOverrideRating()
    {
        if (Yii::$app->request->getIsAjax()) {
            Yii::$app->response->format = Response::FORMAT_JSON;
            if (null === $modelId = (int)Yii::$app->request->post('modelId')) {
                return ['content' => Yii::t('vote', 'modelId has not been sent')];
            }

            $value = (int)Yii::$app->request->post('rate');
            $type = Yii::$app->request->post('type');

            $value = $value ? : null;

            $userId = Yii::$app->user->getId();
            if ($userId === null && !PlaceRating::getIsAllowGuests()) {
                return ['content' => Yii::t('vote', 'Guests are not allowed to vote')];
            }
            if (!$userIp = PlaceRating::compressIp(Yii::$app->request->getUserIP())) {
                return ['content' => Yii::t('vote', 'The user is not recognized')];
            }
            if (!is_int($modelId)) {
                return ['content' => Yii::t('vote', 'The model is not registered')];
            }
            if (PlaceRating::getIsAllowGuests()) {
                $isVoted = PlaceRating::findOne(['model_id' => $modelId, 'user_ip' => $userIp]);
            } else {
                $isVoted = PlaceRating::findOne(['model_id' => $modelId, 'user_id' => $userId]);
            }
            if (is_null($isVoted)) {
                $newVote = new PlaceRating;
                $newVote->model_id = $modelId;
                $newVote->user_id = $userId;
                $newVote->user_ip = $userIp;
                $newVote->$type = $value;
                $newVote->date = time();
                if ($newVote->save()) {
                    return ['content' => Yii::t('vote', 'Thanks for your opinion'), 'success' => true, 'rating' => $newVote->$type];
                } else {
                    return ['content' => Yii::t('vote', 'Validation error')];
                }
            } else {
                if ($isVoted->$type !== $value && PlaceRating::getIsAllowChangeVote()) {
                    $isVoted->$type = $value;
                    if ($isVoted->save()) {
                        return ['content' => Yii::t('vote', 'Your vote has been changed. Thanks!'), 'success' => true, 'changed' => true, 'rating' => $isVoted->$type];
                    } else {
                        return ['content' => Yii::t('vote', 'Validation error')];
                    }
                }
                return ['content' => Yii::t('vote', 'You have already voted!'), 'rating' => $isVoted->$type];
            }
        } else {
            throw new MethodNotAllowedHttpException(Yii::t('vote', 'Forbidden method'), 405);
        }
    }

    public function actionDeleteImage($id, $path)
    {

        $model = PlaceImages::findOne(['place_id' => $id, 'path' => $path]);


        if ($model) {
            $model->delete();
        }

        return $this->redirect(Yii::$app->request->referrer);

    }

}