<?php

namespace backend\modules\places\models;

use bedezign\yii2\audit\AuditTrailBehavior;
use Yii;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "place_rating".
 *
 * @property int $id
 * @property int $model_id
 * @property int $user_id
 * @property resource $user_ip
 * @property int $wheelchair_accessible
 * @property int $spacious_interior
 * @property int $lighting_brightness
 * @property int $quality_of_service
 * @property int $date
 *
 * @property Places $place
 */
class PlaceRating extends \yii\db\ActiveRecord
{
    const allowChangeVote = true;
    const allowGuests = false;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'place_rating';
    }

    public function behaviors()
    {
        return [

            'AuditTrail' => [
                'class' => AuditTrailBehavior::className(),
            ],
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'date',
                'updatedAtAttribute' => 'date',
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['model_id', 'user_ip', 'date'], 'required'],
            [['model_id', 'user_id', 'wheelchair_accessible', 'spacious_interior', 'lighting_brightness', 'quality_of_service', 'date'], 'integer'],
            [['user_ip'], 'string', 'max' => 39],
            [['model_id'], 'exist', 'skipOnError' => true, 'targetClass' => Places::className(), 'targetAttribute' => ['model_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'model_id' => Yii::t('site', 'Model ID'),
            'user_id' => Yii::t('site', 'User ID'),
            'user_ip' => Yii::t('site', 'User Ip'),
            'wheelchair_accessible' => Yii::t('site', 'Wheelchair Accessible'),
            'spacious_interior' => Yii::t('site', 'Spacious Interior'),
            'lighting_brightness' => Yii::t('site', 'Lighting Brightness'),
            'quality_of_service' => Yii::t('site', 'Quality Of Service'),
            'date' => Yii::t('site', 'Date'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPlace()
    {
        return $this->hasOne(Places::className(), ['id' => 'model_id']);
    }

    /**
     * {@inheritdoc}
     * @return PlaceRatingQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new PlaceRatingQuery(get_called_class());
    }


    /**
     * @inheritdoc
     */
    public function afterSave($insert, $changedAttributes)
    {
        static::updateRating($this->attributes['model_id']);
        parent::afterSave($insert, $changedAttributes);
    }


    /**
     * @param string $modelId Id of model
     * @return boolean Checks exists permission for change vote in model params or return global value
     */
    public static function getIsAllowChangeVote()
    {
        return self::allowChangeVote;
    }

    /**
     * @param integer $modelId Id of model
     * @return boolean Checks exists permission for guest voting in model params or return global value
     */
    public static function getIsAllowGuests()
    {
        return self::allowGuests;
    }

    /**
     * @param string $modelId Id of model
     */
    public static function updateRating($modelId)
    {

        $place = Places::findOne($modelId);
        if (!$place) return;

        $isVerified = $place->isVarified();


        $wheelchair_accessible_query = PlaceRating::find()
            ->addSelect(['wheelchair_accessible', 'counter' => 'count(*)', 'total' => 'wheelchair_accessible * count(*)'])
            ->where(['model_id' => $modelId])
            ->andWhere(['not', ['wheelchair_accessible' => null]])
            ->groupBy('wheelchair_accessible');
        if ($isVerified) {
            $wheelchair_accessible_query->andWhere(['user_id' => 1]);//Admin
        }
        $wheelchair_accessible = $wheelchair_accessible_query->asArray()->all();
        $wheelchair_accessible_totals = 0;
        $wheelchair_accessible_sum_totals = 0;

        foreach ($wheelchair_accessible as $wheelchair_accessible_item) {
            $wheelchair_accessible_totals += $wheelchair_accessible_item['counter'];
            $wheelchair_accessible_sum_totals += $wheelchair_accessible_item['total'];
        }

        if ($wheelchair_accessible_totals !== 0)
            $wheelchair_accessible_avg = $wheelchair_accessible_sum_totals / $wheelchair_accessible_totals;
        else
            $wheelchair_accessible_avg = 0;


        $spacious_interior_query = PlaceRating::find()
            ->addSelect(['spacious_interior', 'counter' => 'count(*)', 'total' => 'spacious_interior * count(*)'])
            ->where(['model_id' => $modelId])
            ->andWhere(['not', ['spacious_interior' => null]])
            ->groupBy('spacious_interior');
        if ($isVerified) {
            $spacious_interior_query->andWhere(['user_id' => 1]);//Admin
        }
        $spacious_interior = $spacious_interior_query->asArray()->all();
        $spacious_interior_totals = 0;
        $spacious_interior_sum_totals = 0;

        foreach ($spacious_interior as $spacious_interior_item) {
            $spacious_interior_totals += $spacious_interior_item['counter'];
            $spacious_interior_sum_totals += $spacious_interior_item['total'];
        }

        if ($spacious_interior_totals !== 0)
            $spacious_interior_avg = $spacious_interior_sum_totals / $spacious_interior_totals;
        else
            $spacious_interior_avg = 0;


        $lighting_brightness_query = PlaceRating::find()
            ->addSelect(['lighting_brightness', 'counter' => 'count(*)', 'total' => 'lighting_brightness * count(*)'])
            ->where(['model_id' => $modelId])
            ->andWhere(['not', ['lighting_brightness' => null]])
            ->groupBy('lighting_brightness');
        if ($isVerified) {
            $lighting_brightness_query->andWhere(['user_id' => 1]);//Admin
        }
        $lighting_brightness = $lighting_brightness_query->asArray()->all();
        $lighting_brightness_totals = 0;
        $lighting_brightness_sum_totals = 0;

        foreach ($lighting_brightness as $lighting_brightness_item) {
            $lighting_brightness_totals += $lighting_brightness_item['counter'];
            $lighting_brightness_sum_totals += $lighting_brightness_item['total'];
        }

        if ($lighting_brightness_totals !== 0)
            $lighting_brightness_avg = $lighting_brightness_sum_totals / $lighting_brightness_totals;
        else
            $lighting_brightness_avg = 0;


        $quality_of_service_query = PlaceRating::find()
            ->addSelect(['quality_of_service', 'counter' => 'count(*)', 'total' => 'quality_of_service * count(*)'])
            ->where(['model_id' => $modelId])
            ->andWhere(['not', ['quality_of_service' => null]])
            ->groupBy('quality_of_service');
        //Not include on override
//        if($isVerified){
//            $quality_of_service_query->andWhere(['user_id' => 1]);//Admin
//        }
        $quality_of_service = $quality_of_service_query->asArray()->all();
        $quality_of_service_totals = 0;
        $quality_of_service_sum_totals = 0;

        foreach ($quality_of_service as $quality_of_service_item) {
            $quality_of_service_totals += $quality_of_service_item['counter'];
            $quality_of_service_sum_totals += $quality_of_service_item['total'];
        }

        if ($quality_of_service_totals !== 0)
            $quality_of_service_avg = $quality_of_service_sum_totals / $quality_of_service_totals;
        else
            $quality_of_service_avg = 0;


        $aggregateModel = PlaceAggregateRating::findOne([
            'model_id' => $modelId,
        ]);
        if (null === $aggregateModel) {
            $aggregateModel = new PlaceAggregateRating;
            $aggregateModel->model_id = $modelId;
        }
        $aggregateModel->wheelchair_accessible_avg = $wheelchair_accessible_avg;
        $aggregateModel->spacious_interior_avg = $spacious_interior_avg;
        $aggregateModel->lighting_brightness_avg = $lighting_brightness_avg;
        $aggregateModel->quality_of_service_avg = $quality_of_service_avg;
        $aggregateModel->save();
    }

    /**
     * Converts a printable IP into an unpacked binary string
     *
     * @author Mike Mackintosh - mike@bakeryphp.com
     * @link http://www.highonphp.com/5-tips-for-working-with-ipv6-in-php
     * @param string $ip
     * @return string $bin
     */
    public static function compressIp($ip)
    {
        if (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4)) {
            return current(unpack('A4', inet_pton($ip)));
        } elseif (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV6)) {
            return current(unpack('A16', inet_pton($ip)));
        }
        return false;
    }

    /**
     * Converts an unpacked binary string into a printable IP
     *
     * @author Mike Mackintosh - mike@bakeryphp.com
     * @link http://www.highonphp.com/5-tips-for-working-with-ipv6-in-php
     * @param string $str
     * @return string $ip
     */
    public static function expandIp($str)
    {
        if (strlen($str) == 16 OR strlen($str) == 4) {
            return inet_ntop(pack("A" . strlen($str), $str));
        }
        return false;
    }
}
