<?php

namespace backend\modules\places\models;

use Yii;

/**
 * This is the model class for table "subsector".
 *
 * @property int $id
 * @property int $sector_id
 * @property string $name_en
 * @property string $name_ar
 * @property string $created
 * @property string $updated
 *
 * @property Group[] $groups
 * @property PlaceSubsector[] $placeSubsectors
 * @property Places[] $places
 * @property Sector $sector
 */
class Subsector extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'subsector';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['sector_id', 'name_en'], 'required'],
            [['sector_id'], 'integer'],
            [['created', 'updated'], 'safe'],
            [['name_en', 'name_ar'], 'string', 'max' => 255],
            [['sector_id'], 'exist', 'skipOnError' => true, 'targetClass' => Sector::className(), 'targetAttribute' => ['sector_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'sector_id' => Yii::t('site', 'Sector ID'),
            'name_en' => Yii::t('site', 'Name En'),
            'name_ar' => Yii::t('site', 'Name Ar'),
            'created' => Yii::t('site', 'Created'),
            'updated' => Yii::t('site', 'Updated'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getGroups()
    {
        return $this->hasMany(Group::className(), ['subsector_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPlaceSubsectors()
    {
        return $this->hasMany(PlaceSubsector::className(), ['subsector_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPlaces()
    {
        return $this->hasMany(Places::className(), ['id' => 'place_id'])->viaTable('place_subsector', ['subsector_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getSector()
    {
        return $this->hasOne(Sector::className(), ['id' => 'sector_id']);
    }

    /**
     * {@inheritdoc}
     * @return SubsectorQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new SubsectorQuery(get_called_class());
    }
}
