<?php

namespace backend\modules\places\models;

use bedezign\yii2\audit\AuditTrailBehavior;
use yeesoft\models\User;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "user_save_place".
 *
 * @property int $id
 * @property int $place_id
 * @property int $created_at
 * @property int $created_by
 *
 * @property Places $place
 * @property User $createdBy
 */
class UserSavePlace extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'user_save_place';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['place_id'], 'required'],
            [['place_id', 'created_at', 'created_by'], 'integer'],
            [['place_id'], 'exist', 'skipOnError' => true, 'targetClass' => Places::className(), 'targetAttribute' => ['place_id' => 'id']],
            [['created_by'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['created_by' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [

            'AuditTrail' => [
                'class' => AuditTrailBehavior::className(),
            ],
            'Timestamp' => [
                'class' => TimestampBehavior::className(),
                'updatedAtAttribute' => false,
            ],
            'Blameable' => [
                'class' => BlameableBehavior::className(),
                'updatedByAttribute' => false
            ],
        ];
    }
    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'place_id' => Yii::t('site', 'Place ID'),
            'created_at' => Yii::t('site', 'Created At'),
            'created_by' => Yii::t('site', 'Created By'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPlace()
    {
        return $this->hasOne(Places::className(), ['id' => 'place_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCreatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

}
