<?php

namespace backend\modules\quotes_request\controllers;

use backend\modules\quotes_criteria\models\CarModel;
use backend\modules\quotes_request\forms\MotorInsuranceForm;
use backend\modules\quotes_request\models\MotorInsurance;
use kartik\widgets\ActiveForm;
use Yii;
use yeesoft\controllers\admin\BaseController;
use yii\base\DynamicModel;
use yii\helpers\Json;
use yii\web\Response;

/**
 * MotorController implements the CRUD actions for backend\modules\quotes_request\models\MotorInsurance model.
 */
class MotorController extends BaseController 
{
    public $modelClass       = 'backend\modules\quotes_request\models\MotorInsurance';
    public $modelSearchClass = 'backend\modules\quotes_request\models\search\MotorInsuranceSearch';

    protected function getRedirectPage($action, $model = null)
    {
        switch ($action) {
            case 'update':
                return ['update', 'id' => $model->id];
                break;
            case 'create':
                return ['update', 'id' => $model->id];
                break;
            default:
                return parent::getRedirectPage($action, $model);
        }
    }


    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        /* @var $model \yeesoft\db\ActiveRecord */
        $model = new MotorInsuranceForm();
        $model->setDefaults();
        $model->setScenario('admin');

        if (Yii::$app->request->isAjax) {
            $model->load(Yii::$app->request->post());
            Yii::$app->response->format = Response::FORMAT_JSON;
            $errorMsg = ActiveForm::validate($model);
            return ($errorMsg);
        } elseif ($model->load(Yii::$app->request->post()) && $model->save()) {
            Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been created.'));
            return $this->redirect($this->getRedirectPage('create', $model));
        }

        return $this->renderIsAjax($this->createView, compact('model'));
    }


    /**
     * Updates an existing model.
     * If update is successful, the browser will be redirected to the 'view' page.
     *
     * @param integer $id
     *
     * @return mixed
     * @throws \yii\web\NotFoundHttpException
     */
    public function actionUpdate($id)
    {
        /* @var $model MotorInsuranceForm */
        $model = MotorInsuranceForm::findOne($id);
        $model->setScenario('admin');

        if (Yii::$app->request->isAjax) {
            $model->load(Yii::$app->request->post());
            Yii::$app->response->format = Response::FORMAT_JSON;
            $errorMsg = ActiveForm::validate($model);
            return ($errorMsg);
        } elseif ($model->load(Yii::$app->request->post()) AND $model->save()) {
            Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been updated.'));
            return $this->redirect($this->getRedirectPage('update', $model));
        }

        return $this->renderIsAjax($this->updateView, compact('model'));
    }
    public function actionGetCarModel()
    {
        $out = array();
        //$out[] = ['id' => ' ', 'name' => 'Select ....'];
        if (isset($_POST['depdrop_parents'])) {
            $term_id = end($_POST['depdrop_parents']);
            $list = CarModel::find()->joinWith('translations')
                //->joinWith('carBrand')
                ->andWhere(["car_brand_id" => $term_id])->all();
            if ($term_id != null && count($list) > 0) {
                $selected = '';
                foreach ($list as $i => $item) {
                    $out[] = ['id' => $item->id, 'name' => $item->title];
                }
                // Shows how you can preselect a value
                echo Json::encode(['output' => $out, 'selected' => $selected]);
                return;
            }
        }
        echo Json::encode(['output' => [], 'selected' => '']);
    }


    /**
     *
     * @param integer $id
     *
     * @return mixed
     */
    public function actionAccept($id)
    {
        /* @var $model MotorInsurance */
        $model = MotorInsurance::findOne($id);
        $model->final_price = $model->initial_price;
        $model->request_status = 'Accept By Admin';
        $model->save(false);
        Yii::$app->mailer->compose(
            ['html' => 'motor-accept'], ['model' => $model]
        )
            ->setTo($model->email)
            ->setFrom([Yii::$app->params['adminEmail']])
            ->setSubject(Yii::t('site', 'MotorAcceptSubject'))
            ->send();

        Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been Accepted.'));
        return $this->redirect(Yii::$app->request->referrer);
    }

    /**
     *
     * @param integer $id
     *
     * @return mixed
     */
    public function actionReject($id)
    {
        /* @var $model MotorInsurance */
        $model = MotorInsurance::findOne($id);

        if(Yii::$app->request->isPost){
            $params = Yii::$app->request->post('DynamicModel');
            $model->request_status = 'Rejected By Admin';
            $model->reject_reason = $params['reject_reason'];
            $model->save(false);
            Yii::$app->mailer->compose(
                ['html' => 'motor-reject'], ['model' => $model]
            )
                ->setTo($model->email)
                ->setFrom([Yii::$app->params['adminEmail']])
                ->setSubject(Yii::t('site', 'MotorRejectSubject'))
                ->send();

            Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been Rejected.'));
            return $this->redirect(['/quotes_request/motor/view', 'id' => $model->id]);
        }

        $dynamicModel = new DynamicModel([
            'reject_reason'
        ]);
        $dynamicModel->addRule(['reject_reason'], 'required');

        return $this->render('reject', ['dynamicModel' => $dynamicModel]);


    }


    /**
     *
     * @param integer $id
     *
     * @return mixed
     */
    public function actionChangePrice($id)
    {
        /* @var $model MotorInsurance */
        $model = MotorInsurance::findOne($id);

        if(Yii::$app->request->isPost){
            $params = Yii::$app->request->post('DynamicModel');
            $model->request_status = 'Price Changed By Admin';
            $model->final_price = $params['new_price'];
            $model->save(false);
            Yii::$app->mailer->compose(
                ['html' => 'motor-price-change'], ['model' => $model]
            )
                ->setTo($model->email)
                ->setFrom([Yii::$app->params['adminEmail']])
                ->setSubject(Yii::t('site', 'MotorPriceChangeSubject'))
                ->send();

            Yii::$app->session->setFlash('crudMessage', Yii::t('yee', 'Your item has been updated.'));
            return $this->redirect(['/quotes_request/motor/view', 'id' => $model->id]);
        }

        $dynamicModel = new DynamicModel([
            'new_price'
        ]);
        $dynamicModel->addRule(['new_price'], 'required');
        $dynamicModel->addRule(['new_price'], 'number');

        return $this->render('price_change', ['dynamicModel' => $dynamicModel]);


    }

}