<?php

namespace backend\modules\quotes_request\models;

use bedezign\yii2\audit\AuditTrailBehavior;
use common\helpers\Utility;
use Yii;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "group_medical_insurance".
 *
 * @property int $id
 * @property string $reference_number
 * @property string $title
 * @property string $name
 * @property string $email
 * @property string $mobile_number
 * @property string $company_name
 * @property string $created
 * @property string $updated
 */
class GroupMedicalInsurance extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'group_medical_insurance';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [[ 'name', 'email', 'company_name', 'mobile_number'], 'required'],
            [['reference_number', 'title', 'name', 'email', 'company_name'], 'string', 'max' => 255],
            [['mobile_number'], 'string', 'max' => 50],
            [['email'], 'email'],
            [['created', 'updated'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            AuditTrailBehavior::className(),
            'Timestamp' => [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created',
                'updatedAtAttribute' => 'updated',
            ],
//            BlameableBehavior::className(),
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'reference_number' => Yii::t('site', 'Reference Number'),
            'title' => Yii::t('site', 'Title'),
            'name' => Yii::t('site', 'Name'),
            'email' => Yii::t('site', 'Email'),
            'mobile_number' => Yii::t('site', 'Mobile Number'),
            'company_name' => Yii::t('site', 'Company Name'),
            'created' => Yii::t('site', 'Created'),
            'updated' => Yii::t('site', 'Updated'),
        ];
    }


    public function setDefaults()
    {
        $this->reference_number = Utility::create_guid();
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created);
    }
    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }


    /**
     * {@inheritdoc}
     * @return GroupMedicalInsuranceQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new GroupMedicalInsuranceQuery(get_called_class());
    }
}
