<?php

namespace backend\modules\transcation\models;

use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use yeesoft\media\models\Media;
use yeesoft\models\User;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\TimestampBehavior;
use yii\helpers\Html;

/**
 * This is the model class for table "transcation".
 *
 * @property int $id
 * @property int $reference_no
 * @property int $user_id 
 * @property int $vehicle_id
 * @property int $payment_type
 * @property int $created_at
 * @property int $updated_at
 */
class Transcation extends ActiveRecord
{

    const view_fees = 1;
    const carseer_report_fee = 2;
    const fast_sell_fee = 3;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'transaction_history';
    }

    /**
     * @inheritdoc
     */
    // public function behaviors()
    // {
    //     return [
    //         TimestampBehavior::className(),
    //         BlameableBehavior::className(),
    //         'multilingual' => [
    //             'class' => MultilingualBehavior::className(),
    //             'langForeignKey' => 'parent_id',
    //             'tableName' => "{{%announcement_lang}}",
    //             'attributes' => [
    //                 'title', 'brief', 'content',
    //             ]
    //         ],
    //     ];
    // }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            // [['name'], 'required'],
			// [['name','email', 'phone'], 'required'],
            // [[ 'status','is_document_approved'], 'integer'],
            // [['created_at', 'updated_at'], 'safe'],
			// [[ 'email'], 'string', 'max' => 50],
			// [[ 'email'], 'email'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'reference_no'=>Yii::t('site', 'reference_no'),
            'user_id'=>Yii::t('site', 'user'),
            'vehicle_id'=>Yii::t('site', 'vehicle_id'),
            'payment_type'=>Yii::t('site', 'payment_type'),
            'amount'=>Yii::t('site', 'amount'),
            'status'=>Yii::t('site', 'Status'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),

        ];
    }

    /**
     * {@inheritdoc}
     * @return TranscationQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new TranscationQuery(get_called_class());
    }



    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }


    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public  function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }

    public function getStatusText()
    {
        return $this->getType()[$this->payment_type];
    }
    public static function getType()
    {
        return [
            self::view_fees => Yii::t('yee', '360 View Fee '),
            self::carseer_report_fee => Yii::t('yee', 'Carseer Report Fee'),
            self::fast_sell_fee => Yii::t('yee', 'Fast Sell Fee'),
        ];
    }
    public static function getuser_id($user_id){
        $name='';
        $query = (new \yii\db\Query())->select('*')->from('users')->where(['id' => $user_id]);
         $command = $query->createCommand();
          $data = $command->queryOne();
          if($data){
            $name=$data['name'];
        }else{
            $name='';
        }
        return $name;
    } 
    public static function getvehicle_id($vehicle_id){
        $title='';
        $query = (new \yii\db\Query())->select('*')->from('vehicle_lang')->where(['parent_id' => $vehicle_id]);
         $command = $query->createCommand();
          $data = $command->queryOne();
          if($data){
              $title=$data['title'];
          }else{
              $title='';
          }
          return $title;
    } 
    /**
     *
     * @inheritdoc
     */
    public static function getFullAccessPermission()
    {
        return 'fullPageAccess';
    }

    /**
     * @return Media
     */
    public function getMediaRefObj($fieldName)
    {
        $imgRefObj = Media::findOne(['url' => $this->$fieldName]);

        return $imgRefObj;
    }
 

    public function save($runValidation = true, $attributeNames = null)
    {
        \Yii::$app->cache->flush();
        return parent::save($runValidation, $attributeNames);
    }

}
