<?php

namespace backend\modules\translatemanager\controllers;

use backend\modules\translatemanager\models\Language;
use yii\data\ArrayDataProvider;
use yii\filters\AccessControl;

class TranslatorController extends \lajax\translatemanager\controllers\LanguageController
{
    public $layout = "@backend/views/layouts/main";

    /**
     * @return array
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::class,
                'rules' => [
                    [
                        'allow' => true,
                        'actions' => [
                            'translate',
                            'list',
                            'save'
                        ],
                        'roles' => [
                            '@'
                        ]
                    ]
                ]
            ]
        ];
    }

    /**
     * @return array
     */
    public function actions()
    {
        $actions = parent::actions();
        $actions['save'] =  'lajax\translatemanager\controllers\actions\SaveAction';
        $actions['translate'] = 'backend\modules\translatemanager\controllers\actions\TranslateAction';
        $actions['list'] = 'backend\modules\translatemanager\controllers\actions\ListAction';
        return $actions;
    }

    /**
     * Returns an ArrayDataProvider consisting of language elements.
     * @param array $languageSources
     * @return ArrayDataProvider
     */
    public function createLanguageSourceDataProvider($languageSources)
    {
        $data = [];
        foreach ($languageSources as $category => $messages) {
            foreach ($messages as $message => $boolean) {
                if(in_array($category,[Language::getClientLanguageCategories()])){
                    $data[] = [
                        'category' => $category,
                        'message' => $message,
                    ];
                }
            }
        }

        return new ArrayDataProvider([
            'allModels' => $data,
            'pagination' => false,
        ]);
    }
}