<?php

namespace backend\modules\vehicle\models;

use Yii;
use yii\web\UploadedFile;

/**
 * This is the model class for table "vehicle_images".
 *
 * @property int $id
 * @property int $vehicle_id
 * @property string $path
 * @property string $type
 * @property string $extension
 * @property int $on_front
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property Vehicle $vehicle
 */
class VehicleImages extends \yii\db\ActiveRecord
{
    public $videoFile;

    const ADMIN_OWNER_UPLOADED_THUMB_SIZE = [
        'w' => 265,
        'h' => 150
    ];
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'vehicle_images';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['vehicle_id', 'path'], 'required'],
            [['vehicle_id', 'created_at', 'updated_at', 'created_by', 'updated_by', 'on_front'], 'integer'],
            [['path', 'type','extension'], 'string', 'max' => 255],
            [['vehicle_id'], 'exist', 'skipOnError' => true, 'targetClass' => Vehicle::className(), 'targetAttribute' => ['vehicle_id' => 'id']],
            [['videoFile'],'file'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'vehicle_id' => Yii::t('site', 'Vehicle ID'),
            'path' => Yii::t('site', 'Path'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
            'created_by' => Yii::t('site', 'Created By'),
            'updated_by' => Yii::t('site', 'Updated By'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVehicle()
    {
        return $this->hasOne(Vehicle::className(), ['id' => 'vehicle_id']);
    }

    /**
     * {@inheritdoc}
     * @return VehicleImagesQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new VehicleImagesQuery(get_called_class());
    }
    public function  saveVideo()
    {
        $path = Yii::$app->basePath . '/web/uploads/home-page-video/';

        $this->videoFile = UploadedFile::getInstances($this, 'videoFIle');
        foreach ($this->videoFile as $key => $file) {
            if ($this->videoFile) {
                $base_path = 'home-page-video' . '.' . $file->extension;

                $file->saveAs($path . $base_path);//Upload files to server
            }
        }
    }

    public function getImageFullPath($options=[]){
        $path = ((strpos($this->path, '/') === 0) ? '' : '/').$this->path .".".$this->extension;
        $height = 'auto';
        $width = 'auto';
        $quality = 'auto';
        //tr,w-1600,h-900,q-auto
        if(!empty($options['resolution'])){
            $resolution = explode('x', $options['resolution']);
            $width = $resolution[0];
            $height = $resolution[1];
        }
        if(!empty($options['quality'])){
            $quality = $options['quality'];
        }
        $path = "tr,w-{$width},h-{$height},q-{$quality}".$path;
        return Yii::$app->params['cdnUrl']."/".Yii::getAlias($path);



        if(strpos($this->path, '/front-images/') !== false){
            $path = $this->path .'.'.$this->extension;
            if(!empty($options['resolution'])){
                $path = $this->path ."-{$options['resolution']}.".$this->extension;
            }
            return Yii::$app->params['adminUrl'].Yii::getAlias($path);
        }
        if(strpos($this->path, '/car-listing/') !== false){
            return Yii::$app->params['frontendUrl'].Yii::getAlias($this->path .'.'.$this->extension);
        }

        return Yii::getAlias($this->path .'.'.$this->extension);
    }

    public function getOriginalImageFullPath(){
        if(strpos($this->path, '/front-images/') !== false){
            $path = $this->path .'.'.$this->extension;
            if(!empty($options['resolution'])){
                $path = $this->path ."-{$options['resolution']}.".$this->extension;
            }
            return Yii::$app->params['adminUrl'].Yii::getAlias($path);
        }
        if(strpos($this->path, '/car-listing/') !== false){
            return Yii::$app->params['frontendUrl'].Yii::getAlias($this->path .'.'.$this->extension);
        }

        return Yii::getAlias($this->path .'.'.$this->extension);
    }

    public function removeCdnCache(){
        $cdnCacheFolderPath = $this->getCdnAppBasePath();
        $cdnCacheFolderPathInfo = pathinfo($cdnCacheFolderPath);
        $directories = glob($cdnCacheFolderPathInfo['dirname'] . '/*' , GLOB_ONLYDIR);
        foreach ($directories as $directory){
            $dirFilePath = $directory."/".$cdnCacheFolderPathInfo['basename'];
            if(is_dir($directory) && file_exists($dirFilePath)){
                @unlink($dirFilePath);
            }
        }
    }

    public function getAttachmentFullPath($options=[]){
        $path = ((strpos($this->path, '/') === 0) ? '' : '/').$this->path .".".$this->extension;
        $baseUrl = (strpos($path, '/attachment/') === false) ? Yii::$app->params['adminUrl'] : Yii::$app->params['frontendUrl'];
        return $baseUrl."".Yii::getAlias($path);
    }

    private function getCdnAppBasePath (){

        $mainFolder = '';
        if(strpos($this->path, '/front-images/') !== false){
            $mainFolder = 'backend';
        }else
        if(strpos($this->path, '/car-listing/') !== false){
            $mainFolder = 'frontend';
        }
        $filePath = $this->path.".".$this->extension;
        $cdnAppBasePath = Yii::$app->basePath . '/../frontend/web/cdn-images/'.$mainFolder.'/web'.$filePath;

        return $cdnAppBasePath;
    }
}
