<?php

namespace backend\modules\vehicle\models;

use backend\modules\dropdown_list\models\DropdownList;
use backend\modules\network\models\Category;
use common\models\User;
use yeesoft\behaviors\MultilingualBehavior;
use yeesoft\db\ActiveRecord;
use Yii;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;
use yii\helpers\ArrayHelper;

/**
 * This is the model class for table "vehicle".
 *
 * @property int $id
 * @property int $vehicle_type
 * @property string $slug
 * @property int $status
 * @property int $owner_id
 * @property string $price
 * @property string $model_year
 * @property int $odometer_km
 * @property int $odometer_mile
 * @property string $color_id
 * @property string $interior_color_id
 * @property string $carseer_url
 * @property int $front_left_status
 * @property int $front_right_status
 * @property int $back_left_status
 * @property int $back_right_status
 * @property int $body_type_id
 * @property int $cylinders_id
 * @property int $capacity
 * @property int $engine_id
 * @property int $power
 * @property int $rim_size
 * @property int $transmission_id
 * @property int $drive_id
 * @property string $video_file
 * @property int $manufacturer_id
 * @property int $measuring_the_distance_id
 * @property int $owner_type_id
 * @property int $created_at
 * @property int $updated_at
 * @property int $created_by
 * @property int $updated_by
 * @property int $is_featured
 * @property int $is_sold
 * @property int $car_type
 * @property int $image_counter
 *
 * @property VehicleAttachment[] $vehicleAttachments
 * @property DropdownList[] $attachments
 * @property VehicleEquipment[] $vehicleEquipments
 * @property DropdownList[] $equipment
 * @property VehicleImages[] $vehicleImages
 * @property Vehicle360Images[] $vehicle360Images
 * @property VehicleLang[] $vehicleLangs
 * @property VehicleRemark[] $vehicleRemarks
 * @property DropdownList[] $remarks
 */
class Vehicle extends ActiveRecord
{


    const STATUS_PENDING = 0;
    const STATUS_PUBLISHED = 1;
    const COMMENT_STATUS_CLOSED = 0;
    const COMMENT_STATUS_OPEN = 1;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'vehicle';
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            TimestampBehavior::className(),
            BlameableBehavior::className(),
            'sluggable' => [
                'class' => SluggableBehavior::className(),
                'attribute' => 'title',
                'ensureUnique' => true,
            ],
            'multilingual' => [
                'class' => MultilingualBehavior::className(),
                'langForeignKey' => 'parent_id',
                'tableName' => "{{%vehicle_lang}}",
                'attributes' => [
                    'title', 'description',
                ]
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['title', 'owner_id', 'owner_type_id', 'body_type_id', 'capacity', 'engine_id', 'power', 'transmission_id', 'drive_id', 'rim_size', 'cylinders_id','manufacturer_id','manufacturer_model_id'], 'required'],
            [['owner_type_id', 'status', 'owner_id', 'odometer_km', 'odometer_mile',  'front_left_status', 'front_right_status', 'back_left_status', 'back_right_status', 'body_type_id', 'cylinders_id', 'capacity', 'engine_id', 'power', 'rim_size', 'transmission_id', 'drive_id', 'manufacturer_id','measuring_the_distance_id', 'created_at', 'updated_at', 'created_by', 'updated_by','manufacturer_model_id','vehicle_type'], 'integer'],
            [['price'], 'number'],
            [['model_year','image_counter'], 'safe'],
            [['carseer_url'],'safe'],
            [['is_featured'], 'boolean'],
            [['is_sold'], 'boolean'],
            [['car_type'], 'integer'],
            [['slug', 'video_file'], 'string', 'max' => 255],
            [['color_id', 'interior_color_id'],'safe']
        ];
    }

    
    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('site', 'ID'),
            'slug' => Yii::t('site', 'Slug'),
            'status' => Yii::t('site', 'Status'),
            'owner_id' => Yii::t('site', 'Owner'),
            'owner_type_id' => Yii::t('site', 'Owner Type'),
            'price' => Yii::t('site', 'Price'),
            'model_year' => Yii::t('site', 'Model Year'),
            'odometer_km' => Yii::t('site', 'Odometer Km'),
            'odometer_mile' => Yii::t('site', 'Odometer Mile'),
            'color_id' => Yii::t('site', 'Color ID'),
            'interior_color_id' => Yii::t('site', 'Interior Color ID'),
            'front_left_status' => Yii::t('site', 'Front Left Status'),
            'front_right_status' => Yii::t('site', 'Front Right Status'),
            'back_left_status' => Yii::t('site', 'Back Left Status'),
            'back_right_status' => Yii::t('site', 'Back Right Status'),
            'body_type_id' => Yii::t('site', 'Body Type ID'),
            'cylinders_id' => Yii::t('site', 'Cylinders ID'),
            'capacity' => Yii::t('site', 'Capacity'),
            'engine_id' => Yii::t('site', 'Engine ID'),
            'image360' => Yii::t('site', 'Image 360'),
            'power' => Yii::t('site', 'Power'),
            'rim_size' => Yii::t('site', 'Rim Size'),
            'transmission_id' => Yii::t('site', 'Transmission ID'),
            'drive_id' => Yii::t('site', 'Drive ID'),
            'video_file' => Yii::t('site', 'Video File'),
            'manufacturer_id' => Yii::t('site', 'Manufacturer ID'),
            'car_type' => Yii::t('site', 'Car Type'),
            'measuring_the_distance_id' => Yii::t('site', 'Measuring The Distance'),
            'created_at' => Yii::t('site', 'Created At'),
            'updated_at' => Yii::t('site', 'Updated At'),
            'created_by' => Yii::t('site', 'Created By'),
            'updated_by' => Yii::t('site', 'Updated By'),
            'carseer_url'=> Yii::t('site', 'Carseer Url'),
        ];
    }

    /**
     * @inheritdoc
     */
    public function init()
    {
        parent::init();

        $this->on(self::EVENT_AFTER_INSERT, [$this, 'saveEquipments']);
        $this->on(self::EVENT_AFTER_UPDATE, [$this, 'saveEquipments']);
        $this->on(self::EVENT_AFTER_UPDATE, [$this, 'sendNotification']);
        $this->on(self::EVENT_AFTER_INSERT, [$this, 'saveRemarks']);
        $this->on(self::EVENT_AFTER_UPDATE, [$this, 'saveRemarks']);
        // $this->on(self::EVENT_AFTER_INSERT, [$this, 'saveAttachments']);
        // $this->on(self::EVENT_AFTER_UPDATE, [$this, 'saveAttachments']);
        $this->on(self::EVENT_AFTER_INSERT, [$this, 'saveImages']);
        $this->on(self::EVENT_AFTER_UPDATE, [$this, 'saveImages']);
        // $this->on(self::EVENT_AFTER_INSERT, [$this, 'save360Images']);
        // $this->on(self::EVENT_AFTER_UPDATE, [$this, 'save360Images']);
        $this->on(self::EVENT_AFTER_INSERT, [$this, 'saveAttachmentsFiles']);
        $this->on(self::EVENT_AFTER_UPDATE, [$this, 'saveAttachmentsFiles']);
    }


    /**
     * {@inheritdoc}
     * @return VehicleQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new VehicleQuery(get_called_class());
    }

    public static function populateFromSolr($doc)
    {

        return Vehicle::findOne($doc['id']);
    }

    public function getAuthor()
    {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    public function getUpdatedBy()
    {
        return $this->hasOne(User::className(), ['id' => 'updated_by']);
    }

    public function getPublishedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedDate()
    {
        return Yii::$app->formatter->asDate(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->published_at);
    }

    public function getCreatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->created_at);
    }

    public function getUpdatedTime()
    {
        return Yii::$app->formatter->asTime(($this->isNewRecord) ? time() : $this->updated_at);
    }

    public function getPublishedDatetime()
    {
        return "{$this->publishedDate} {$this->publishedTime}";
    }

    public function getCreatedDatetime()
    {
        return "{$this->createdDate} {$this->createdTime}";
    }

    public function getUpdatedDatetime()
    {
        return "{$this->updatedDate} {$this->updatedTime}";
    }

    /**
     * getTypeList
     * @return array
     */
    public static function getStatusList()
    {
        return [
            self::STATUS_PUBLISHED => Yii::t('yee', 'Published'),
            self::STATUS_PENDING => Yii::t('yee', 'Pending'),
        ];
    }

    /**
     * getStatusOptionsList
     * @return array
     */
    public static function getStatusOptionsList()
    {
        return [
            [self::STATUS_PENDING, Yii::t('yee', 'Pending'), 'default'],
            [self::STATUS_PUBLISHED, Yii::t('yee', 'Published'), 'primary']
        ];
    }

    public function getOwner()
    {
        return $this->hasOne(Owner::className(), ['id' => 'owner_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVehicleAttachments()
    {
        return $this->hasMany(VehicleAttachment::className(), ['vehicle_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getAttachments()
    {
        return $this->hasMany(DropdownList::className(), ['id' => 'attachment_id'])->viaTable('vehicle_attachment', ['vehicle_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVehicleEquipments()
    {
        return $this->hasMany(VehicleEquipment::className(), ['vehicle_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEquipment()
    {
        return $this->hasMany(DropdownList::className(), ['id' => 'equipment_id'])->viaTable('vehicle_equipment', ['vehicle_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVehicleImages()
    {
        return $this->hasMany(VehicleImages::className(), ['vehicle_id' => 'id'])->andWhere(['type' => 'basic'])->orderBy(['on_front' => SORT_DESC]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVehicle360Images()
    {
        return $this->hasMany(VehicleImages::className(), ['vehicle_id' => 'id'])->andWhere(['type' => '360']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getAttachmentsFiles()
    {
        return $this->hasMany(VehicleImages::className(), ['vehicle_id' => 'id'])->andWhere(['type' => 'attachmentsFiles']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVehicleLangs()
    {
        return $this->hasMany(VehicleLang::className(), ['parent_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVehicleRemarks()
    {
        return $this->hasMany(VehicleRemark::className(), ['vehicle_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getRemarks()
    {
        return $this->hasMany(DropdownList::className(), ['id' => 'remark_id'])->viaTable('vehicle_remark', ['vehicle_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getOwnerType()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'owner_type_id'])->andFilterWhere(['category' => DropdownList::VehicleOwnerType]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getBodyType()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'body_type_id'])->andFilterWhere(['category' => DropdownList::VehicleBodyType]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCylinders()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'cylinders_id'])->andFilterWhere(['category' => DropdownList::VehicleCylinders]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEngine()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'engine_id'])->andFilterWhere(['category' => DropdownList::VehicleEngine]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getTransmission()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'transmission_id'])->andFilterWhere(['category' => DropdownList::VehicleTransmission]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getDrive()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'drive_id'])->andFilterWhere(['category' => DropdownList::VehicleDrive]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getColor()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'color_id'])->andFilterWhere(['category' => DropdownList::VehicleColors]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getInteriorColor()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'interior_color_id'])->andFilterWhere(['category' => DropdownList::VehicleInteriorColor]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getManufacturer()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'manufacturer_id'])->andFilterWhere(['category' => DropdownList::VehicleManufacturer]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getManufacturerModel()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'manufacturer_model_id'])->andFilterWhere(['category' => DropdownList::VehicleModelManufacturer]);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getMeasuringTheDistance()
    {
        return $this->hasOne(DropdownList::className(), ['id' => 'measuring_the_distance_id'])->andFilterWhere(['category' => DropdownList::MeasuringTheDistance]);
    }


    public function getEquipmentValues()
    {

        return ArrayHelper::map(VehicleEquipment::find()->where(['vehicle_id' => $this->id])->asArray()->all(), 'equipment_id', 'equipment_id');
    }

    public function getAttachmentValues()
    {

        return ArrayHelper::map(VehicleAttachment::find()->where(['vehicle_id' => $this->id])->asArray()->all(), 'attachment_id', 'attachment_id');
    }

    public function getRemarkValues()
    {

        return ArrayHelper::map(VehicleRemark::find()->where(['vehicle_id' => $this->id])->asArray()->all(), 'remark_id', 'remark_id');
    }


    /**
     * Handle save tags event of the owner.
     */
    public function saveImages()
    {
        /** @var Vehicle $owner */
       $owner = $this->id;

        $post = Yii::$app->getRequest()->post('Vehicle');
        $images = (isset($post['images'])) ? $post['images'] : null;

        if (is_array($images)) {
            foreach ($images as $img) {
                VehicleImages::deleteAll(['vehicle_id' => $owner, 'path' => $img]);
                $linkImage = new VehicleImages();
                $linkImage->path = $img;
                $linkImage->vehicle_id = $this->id;
                $linkImage->type = 'basic';
                $linkImage->save();
            }
        }
    }

    /**
     * Handle save tags event of the owner.
     */
    public function save360Images()
    {
        /** @var Vehicle $owner */
       $owner = $this->owner;

       
        $post = Yii::$app->getRequest()->post('Vehicle');
        $images = (isset($post['images360'])) ? $post['images360'] : null;
        if (is_array($images)) {
            foreach ($images as $img) {
                VehicleImages::deleteAll(['vehicle_id' => $owner, 'path' => $img]);
                $linkImage = new VehicleImages();
                $linkImage->path = $img;
                $linkImage->vehicle_id = $this->id;
                $linkImage->type = '360';
                $linkImage->save();
            }
        }
    }


        /**
         * Handle save tags event of the owner.
         */
        public function saveAttachmentsFiles()
        {
            /** @var Vehicle $owner */
           $owner = $this->owner;

            $post = Yii::$app->getRequest()->post('Vehicle');

            $files = (isset($post['attachmentsFiles'])) ? $post['attachmentsFiles'] : null;
            if (is_array($files)) {
                foreach ($files as $file) {
                    VehicleImages::deleteAll(['vehicle_id' => $owner, 'path' => $file]);
                    $linkImage = new VehicleImages();
                    $linkImage->path = $file;
                    $linkImage->vehicle_id = $this->id;
                    $linkImage->type = 'attachmentsFiles';
                    $linkImage->save();
                }
            }
        }


    /**
     * Handle save tags event of the owner.
     */
    public function saveEquipments()
    {
        /** @var Vehicle $owner */
       $owner = $this->owner;

        $equipmentValues = @Yii::$app->getRequest()->post('Vehicle')['equipmentValues'];

        // VehicleEquipment::deleteAll(['vehicle_id' => $owner]);
        VehicleEquipment::deleteAll(['vehicle_id' => $this->id]);

        if (is_array($equipmentValues)) {
            foreach ($equipmentValues as $accessibility) {
                $linkImage = new VehicleEquipment();
                $linkImage->equipment_id = $accessibility;
                $linkImage->vehicle_id = $this->id;
                $linkImage->save();
            }
        }
    }

    /**
     * Handle save tags event of the owner.
     */
    public function saveAttachments()
    {
        /** @var Vehicle $owner */
       $owner = $this->owner;

        $attachmentValues = @Yii::$app->getRequest()->post('Vehicle')['attachmentValues'];

        // VehicleAttachment::deleteAll(['vehicle_id' => $owner]);
        VehicleAttachment::deleteAll(['vehicle_id' => $this->id]);

        if (is_array($attachmentValues)) {
            foreach ($attachmentValues as $accessibility) {
                $linkImage = new VehicleAttachment();
                $linkImage->attachment_id = $accessibility;
                $linkImage->vehicle_id = $this->id;
                $linkImage->save();
            }
        }
    }

    /**
     * Handle save tags event of the owner.
     */
    public function saveRemarks()
    {
        /** @var Vehicle $owner */
       $owner = $this->owner;

        $remarkValues = @Yii::$app->getRequest()->post('Vehicle')['remarkValues'];

        // VehicleRemark::deleteAll(['vehicle_id' => $owner]);
        VehicleRemark::deleteAll(['vehicle_id' => $this->id]);

        if (is_array($remarkValues)) {
            foreach ($remarkValues as $accessibility) {
                $linkImage = new VehicleRemark();
                $linkImage->remark_id = $accessibility;
                $linkImage->vehicle_id = $this->id;
                $linkImage->save();
            }
        }
    }


    public function save($runValidation = true, $attributeNames = null)
    {
        \Yii::$app->cache->flush();
        return parent::save($runValidation, $attributeNames);
    }

    /**
     * @param int $body_type_id
     */
    public function getPricejod(){
        return $this->price.Yii::t('site','JOD');
    }

    public function sendNotification(){

        if($this->status == 1){
            $row = (new \yii\db\Query())
                ->select(['id', 'email'])
                ->from('users')
                ->where(['owner_id' => $this->owner_id])
                ->one();

            $title = '';
            if(isset($this->vehicleLangs[0])){
                $title = $this->vehicleLangs[0]->title;
            }
            if(!empty($row)){
                $this->sendNotificationRequest($row['id'],'Car Approved','Your ('.$title.') has been approved',$this->id,$this->owner_id,'Car Approved',2);
            }

            return true;

        }
        return false;
    }

    public function sendNotificationRequest($user_id,$title,$body,$car_id = 0,$owner_id = 0,$type = 'Car Bid',$type_id = 1){
        $url = 'https://autostudio.jo/auto/public/api/v1/send-web-notification';

// Create a new cURL resource
        $ch = curl_init($url);

// Setup request to send json via POST
        $data = array(
            'user_id' => $user_id,
            'title' => $title,
            'body' => $body,
            'owner_id' => $owner_id,
            'car_id' => $car_id,
            'type' => $type,
            'type_id' => $type_id,
        );

        // $payload = json_encode(array("user" => $data));

// Attach encoded JSON string to the POST fields
        curl_setopt($ch, CURLOPT_POSTFIELDS, $data);

// Set the content type to application/json
        //curl_setopt($ch, CURLOPT_HTTPHEADER, array());

// Return response instead of outputting
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

// Execute the POST request
        $result = curl_exec($ch);
        /*echo '<pre>';
        print_r($result);
        echo '/<pre>';*/
// Close cURL resource
        curl_close($ch);

       return true;
    }
}
