<?php

namespace common\helpers;

use common\models\Notifications;
use common\models\NotificationsType;
use common\models\Users;
use common\models\Vehicle;
use common\models\VehicleBids;
use common\models\VehicleImages;
use Yii;

class NotificationsHelper
{
    public static function sendAndSaveNotification($type, $data){


        try {
            switch ($type){
                case 'bid_placed':
                    if($data instanceof VehicleBids){

                        $bidderDetails = $data->user;
                        if(empty($bidderDetails)){
                            throw new \Exception('No bidder details found.');
                        }

                        $vehicleDetails = $data->vehicle;
                        if(empty($vehicleDetails)){
                            throw new \Exception('No vehicle details found.');
                        }
                        $vehicleUserDetails = $vehicleDetails->user;

                        if(empty($vehicleUserDetails)){
                            throw new \Exception('No vehicle user details found.');
                        }

                        $notificationType = self::getNotificationTypeData(NotificationsType::$BID_NOTIFICATION_TYPE);
                        if(empty($notificationType)){
                            throw new \Exception('No notification type details found.');
                        }

                        /*
                         * vehicle image
                         * */
                        $vehicleImage = '';
                        $vehicleImageData = VehicleImages::findOne(['vehicle_id' => $vehicleDetails->id, 'type' => 'images']);
                        if(!empty($vehicleImageData)){
                            $vehicleImage = $vehicleImageData->getImageFullPath();
                        }

                        $info = [
                            'user_id'=>$bidderDetails->id,
                            'owner_id'=>$vehicleUserDetails->owner_id,
                            'type_id'=>$notificationType->id,
                            'vehicle_id'=>$vehicleDetails->id,
                            'type'=>'',
                        ];

                        $notificationTitle = 'Bid On Vehicle';
                        $notificationBody = Yii::t('auto', "{user_fullname} bid ({price}) on your vehicle", [
                            'user_fullname' => $bidderDetails->name,
                            'price' => $data->bid,
                        ]);
                        //echo "<pre>";print_r($vehicleUserDetails);echo "</pre>";die('Call');
                        if(!empty($vehicleUserDetails->device_key)){
                            PushNotifications::android($info, $vehicleUserDetails->device_key, $notificationTitle, $notificationBody);
                        }

                        $json = json_encode($info);
                        unset($info['vehicle_id']);
                        unset($info['type']);
                        $info['json_data'] = $json;
                        $info['title'] = $notificationTitle;
                        $info['message'] = $notificationBody;
                        $info['image'] = $vehicleImage;
                        $info['object_id'] = $vehicleDetails->id;
                        self::saveNotification($info);
                    }
                    break;
            }
        }catch (\Exception $e){


        }

    }

    public static function saveNotification($data){
        $data['is_read'] = 0;
        $modelData = [
            'Notifications' => $data
        ];
        $notification = new Notifications();
        $notification->load($modelData);
        if(!$notification->save()){}
    }

    public static function getNotificationTypeData($type){
        $notificationType = NotificationsType::findOne(['type' => $type]);
        return $notificationType;
    }

    public static function getCurrentUserNotificationsCount(){
        return Notifications::find()->where(['is_read' => 0, 'owner_id' => Yii::$app->user->identity->owner_id])->count();
    }
}
