<?php

namespace common\models;

use backend\modules\vehicle\models\Owner;
use Yii;

/**
 * This is the model class for table "vehicle".
 *
 * @property int $id
 * @property int $user_id
 * @property string $full_name
 * @property string $email
 * @property int $phone_number
 * @property string|null $slug
 * @property string $title
 * @property int|null $status
 * @property int|null $owner_id
 * @property int|null $owner_type_id
 * @property int|null $is_featured
 * @property float|null $price
 * @property int|null $vehicle_type
 * @property string|null $model_year
 * @property int|null $odometer_km
 * @property int|null $odometer_mile
 * @property string|null $color_id
 * @property string|null $interior_color_id
 * @property int|null $front_left_status
 * @property int|null $front_right_status
 * @property int|null $back_left_status
 * @property int|null $back_right_status
 * @property int|null $body_type_id
 * @property int|null $cylinders_id
 * @property int|null $capacity
 * @property int|null $engine_id
 * @property int|null $power
 * @property int|null $rim_size
 * @property int|null $transmission_id
 * @property int|null $drive_id
 * @property int|null $image_counter
 * @property string|null $video_file
 * @property int|null $manufacturer_id
 * @property int|null $measuring_the_distance_id
 * @property string|null $carseer_url
 * @property int|null $created_at
 * @property int|null $updated_at
 * @property int|null $created_by
 * @property int|null $updated_by
 * @property int|null $manufacturer_model_id
 * @property string|null $image360
 * @property int|null $is_sold
 * @property int|null $is_private
 * @property int|null $car_type
 * @property int $approved_at
 * @property string|null $phone
 * @property int|null $is_accidental
 * @property  string $other_information
 * @property int $sell_as
 *
 * @property VehicleImages $vehicleImages[]
 */


class Vehicle extends \yii\db\ActiveRecord
{

    const INACTIVE = 0;
    const PENDING = 1;
    const ACTIVE = 2;

    const FREE = 1;
    const ROUND = 2;
    const FAST  = 3;

    const VEHICLE_TYPE_USER_CARS_FOR_SALE = 1;
    const VEHICLE_TYPE_NEW_CAR_DEALS = 2;
    const VEHICLE_TYPE_CERTIFIED_PRE_OWNED = 3;


    const CAR_TYPE_FREE = 1;
    const CAR_TYPE_ROUND = 2;
    const CAR_TYPE_FAST  = 3;

    const IS_INACTIVE = 'Inactive';
    const IS_PENDING = 'Pending';
    const IS_ACTIVE = 'Success';
    const IS_PUBLISHED = 'Published';
    const IS_DRAFT = 'Draft';

    const VEHICLE_FREE = 'free_listing';
    const VEHICLE_FAST = 'auction';
    const VEHICLE_ROUND = '360_listing';

    const VEHICLE_FREE_NAME = 'Free Car Listing';
    const VEHICLE_FAST_NAME = 'Fast Car Listing';
    const VEHICLE_ROUND_NAME = '360 Car Listing';
    const VEHICLE_LIVE = 'Live';
    const VEHICLE_FINISHED = 'Finished';

    const USED_CAR_FOR_SALE = 1;
    const NEW_CAR_DEALS = 2;
    const CERTIFIED_PRE_OWNED = 3;

    const ENGLISH_LANGUAGE = 'en';
    const ENGLISH_LANGUAGE2 = 'en-US';
    const ARABIC_LANGUAGE = 'ar';

    const COUNT_TWO = 2;

    const YES = 1;
    const NO = 0;

    const IS_SOLD = 1;
    const IS_NOT_SOLD = 0;

    const PUBLISHED = 2;
    const NOT_PUBLISHED = 1;

    const IS_FEATURED = 1;
    const IS_NOT_FEATURED =0;

    public $remark;
    public $equipment;
    public $attachment;
    public $price_from;
    public $price_to;
    public $distance_km_from;
    public $distance_km_to;
    public $distance_mile_from;
    public $distance_mile_to;
    public $vin_number;

    public $has_carseer_report;
    public $odometer_meter_type;

    public $buy_carseer_report;
    public $pay_360_online_fees;

    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'vehicle';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['user_id', 'full_name', 'email', 'phone_number', 'vehicle_type','body_type_id','cylinders_id', 'capacity', 'engine_id', 'power', 'rim_size', 'sell_as', 'transmission_id', 'drive_id', 'manufacturer_id', 'manufacturer_model_id','title','price' ,'rim_size','power','capacity','has_carseer_report', 'model_year','color_id', 'interior_color_id'], 'required','on'=>self::SCENARIO_DEFAULT],

            [['user_id', 'status', 'owner_id', 'owner_type_id', 'is_featured', 'vehicle_type', 'odometer_km', 'odometer_mile', 'front_left_status', 'front_right_status', 'back_left_status', 'back_right_status', 'body_type_id', 'cylinders_id', 'capacity', 'engine_id', 'power', 'rim_size', 'transmission_id', 'drive_id', 'image_counter', 'manufacturer_id', 'measuring_the_distance_id', 'created_at', 'updated_at', 'created_by', 'updated_by', 'manufacturer_model_id', 'is_sold', 'is_private', 'car_type', 'is_accidental'], 'integer'],

            [
                'price', 'number', 'min' => 1, 'when' => function ($model) {
                    return $model->car_type == Vehicle::CAR_TYPE_FAST;
            }, 'whenClient' => "function (attribute, value) {
                    return $('input[name=\"Vehicle[car_type]\"]').val() == ".Vehicle::CAR_TYPE_FAST."
                }",
                'tooSmall' => Yii::t('auto', 'The value must be greater than Zero(0).')
            ],
            [['phone_number'], 'number'],

            [['vin_number'], 'string'],

            [['vin_number'],'required', 'on' => 'check_vin'],
            ['attachment', 'required',
                'whenClient' => 'function(){ return $(\'input[name="Vehicle[car_type]"]\').val() == '.self::FAST.' }',
                'when' => function($model) {
                    return $model->car_type == self::FAST;
                }
            ],
            ['buy_carseer_report', 'required',
                'whenClient' => 'function(){ return  $(\'input[name="Vehicle[has_carseer_report]"]:checked\').val() != 1 && $(\'input[name="Vehicle[car_type]"]\').val() == '.self::FAST.' }'
            ],

            [['equipment','remark', 'approved_at'], 'safe'],

            [['full_name', 'title'], 'string', 'max' => 125],

            [['other_information'], 'string', 'max' => 1250],

            [['email'], 'email'],

            [['slug', 'video_file', 'carseer_url', 'image360'], 'string', 'max' => 255],

            [['phone'], 'string', 'max' => 20],
            [['sell_as'], 'integer'],
            ['video_file','url'],
            /*['full_name', 'match',
                'pattern' => '/^([a-zA-Z]+\s)*[a-zA-Z]+$/',
                'message' => Yii::t('auto','Invalid characters in full name, only alphabets allowed'),
            ],*/

            [['pay_360_online_fees'], 'integer'],

        ];
    }

    public function scenarios()
    {
        $scenarios = parent::scenarios();
        $scenarios['auction_form'] = ['attachment'];
        return $scenarios;
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'title' => Yii::t('auto','Title'),
            'user_id' => Yii::t('auto','User Name'),
            'full_name' => Yii::t('auto','Full Name'),
            'email' => Yii::t('auto','Email'),
            'phone_number' => Yii::t('auto','Phone Number'),
            'slug' => Yii::t('auto','Slug'),
            'status' => Yii::t('auto','Status'),
            'owner_id' => 'Owner ID',
            'owner_type_id' => 'Owner Type ID',
            'is_featured' => 'Is Featured',
            'price' => Yii::t('auto','Price'),
            'vehicle_type' => Yii::t('auto','Vehicle Type'),
            'model_year' => Yii::t('auto','Model Year'),
            'odometer_km' => Yii::t('auto','Odometer Km'),
            'odometer_mile' => Yii::t('auto','Odometer Mile'),
            'color_id' => Yii::t('auto','Exterior Color'),
            'interior_color_id' => Yii::t('auto','Interior Color'),
            'front_left_status' => 'Front Left Status',
            'front_right_status' => 'Front Right Status',
            'back_left_status' => 'Back Left Status',
            'back_right_status' => 'Back Right Status',
            'body_type_id' => Yii::t('auto','Body Type'),
            'cylinders_id' => Yii::t('auto','Cylinders'),
            'capacity' => Yii::t('auto','Capacity (Example 2000, 3500, 5000 c.c)'),
            'engine_id' => Yii::t('auto','Engine'),
            'power' => Yii::t('auto','Power (Example 130, 200, 420 horsepower)'),
            'rim_size' => Yii::t('auto','Rim Size (Example 16, 18, 22)'),
            'transmission_id' => Yii::t('auto','Transmission'),
            'drive_id' => Yii::t('auto','Drive'),
            'image_counter' => Yii::t('auto','Image Counter'),
            'video_file' => Yii::t('auto','Video File'),
            'manufacturer_id' => Yii::t('auto','Manufacturer'),
            'measuring_the_distance_id' => Yii::t('auto','Air intake Booster'),
            'carseer_url' => Yii::t('auto','Carseer Url'),
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
            'created_by' => 'Created By',
            'updated_by' => 'Updated By',
            'equipment' => Yii::t('auto','Equipments'),
            'remark' => Yii::t('auto','Remarks'),
            'vin_number' => Yii::t('auto','Vin Number'),
            'manufacturer_model_id' => Yii::t('auto','Manufacturer Model'),
            'image360' => 'image360',
            'is_sold' => 'Is Sold',
            'is_private' => 'Is Private',
            'car_type' => Yii::t('auto','Car Type'),
            'phone' => Yii::t('auto','Phone'),
            'is_accidental' => 'Is Accidental',
            'attachment' => ($this->car_type != self::FAST) ? Yii::t('auto','Inspection Report (Optional)') : Yii::t('auto','Inspection Report'),
            'other_information' => Yii::t('auto','Other Information'),
        ];
    }

    public function getFavourite($user_id,$vehicle_id)
    {
        $model = \common\models\FavoriteVehicle::findOne(['user_id' => $user_id, 'vehicle_id' => $vehicle_id]);

        if ($model) {
            return true;
        }else{
            return false;
        }
    }
    public function getImages()
    {
        return $this->hasMany(VehicleImages::class,['vehicle_id' => 'id']);
    }

    /**
     * @param $field
     * @return string|null
     */
    public function getData($field){
        $object = DropdownListLang::findOne(['parent_id' => $this->$field,'language' => Yii::$app->params['short_language']]);
        if(!$object){
            $object = DropdownListLang::findOne(['parent_id' => $this->$field]);
        }
        if($object){
            return $object->title;
        }
        return '-';
    }

    public function isAuctionExpired(){
        return (time()) >= ($this->updated_at + (60*60*24*2));
    }

    public function getExpiration(){
        if(!$this->isAuctionExpired()){
            return  ($this->updated_at + (60*60*24*2)) - (time());
        }
        return 0;
    }

    public function getUser(){
        return $this->hasOne(Users::class, ['id' => 'user_id']);
    }

    public function getOwner(){
        return $this->hasOne(Owner::class, ['id' => 'owner_id']);
    }

    /**
     * Sends an email to the specified email address using the information collected by this model.
     *
     *
     * @return bool whether the email was sent
     */
    public function sendEmailToNotifyAdmin()
    {

        return Yii::$app->mailer
            ->compose(
                ['html' => 'new-vehicle-listed-html', 'text' => 'new-vehicle-listed-text'],
                [
                    'user' => $this->user,
                    'model' => $this
                ]
            )
            ->setTo(Yii::$app->params['senderEmail'])
            ->setFrom([Yii::$app->params['senderEmail'] => Yii::$app->params['senderName']])
            ->setSubject('New Vehicle Listed ' . Yii::$app->name)
            ->send();
    }


    /**
     * Sends an email to the specified email address using the information collected by this model.
     *
     *
     * @return bool whether the email was sent
     */
    public function sendEmailToNotifyPaymentSuccess()
    {

        $vehicle_title = \common\models\VehicleLang::findOne(['parent_id' => $this->id,'language' => Yii::$app->params['short_language']]);
        return Yii::$app->mailer
            ->compose(
                ['html' => 'new-vehicle-payment-html', 'text' => 'new-vehicle-listed-text'],
                ['model' => $this]
            )
            ->setTo(Yii::$app->params['senderEmail'])
            ->setFrom([Yii::$app->params['senderEmail'] => Yii::$app->params['senderName']])
            ->setSubject("Payment Made for Vehicle : {$vehicle_title->title} - " . Yii::$app->name)
            ->send();
    }

    public function isVehicleOwnerTypeDealership(){
        $ownerTypeNameData = DropdownListLang::findOne(['title' => 'Dealership', 'language' => 'en-US']);
        return $this->owner_type_id == $ownerTypeNameData->parent_id;
    }

    public function isVehicleOwnerTypeShowrooms(){
        $ownerTypeNameData = DropdownListLang::findOne(['title' => 'Showrooms', 'language' => 'en-US']);
        return $this->owner_type_id == $ownerTypeNameData->parent_id;
    }

    public function isVehicleOwnerTypePrivateOwner(){
        $ownerTypeNameData = DropdownListLang::findOne(['title' => 'Private Owner', 'language' => 'en-US']);
        return $this->owner_type_id == $ownerTypeNameData->parent_id;
    }

    public function getImage360Panaroma(){
        if(empty($this->image360)){  return false; }
        return Yii::$app->params['adminUrl'].Yii::getAlias($this->image360);
    }
}
