<?php

namespace common\models;

use Yii;

/**
 * This is the model class for table "vehicle_images".
 *
 * @property int $id
 * @property int $vehicle_id
 * @property string $path
 * @property string|null $extension
 * @property string|null $type
 * @property int|null $on_front
 * @property int|null $created_at
 * @property int|null $updated_at
 * @property int|null $created_by
 * @property int|null $updated_by
 * @property int|null $is_api
 * @property Vehicle $vehicle
 */
class VehicleImages extends \yii\db\ActiveRecord
{
    const TYPE_ONE = 'images';
    const TYPE_TWO = 'attachmentFile';
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'vehicle_images';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['vehicle_id', 'path'], 'required'],
            [['vehicle_id', 'on_front', 'created_at', 'updated_at', 'created_by', 'updated_by', 'is_api'], 'integer'],
            [['extension'], 'string'],
            [['path'], 'file', 'maxFiles' => 55],
            [['type'], 'string', 'max' => 255],
        ];
    }

    public $frontImage;
    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'vehicle_id' => Yii::t('auto','Vehicle Name'),
            'path' => Yii::t('auto','Path'),
            'extension' => Yii::t('auto','Extension'),
            'type' => Yii::t('auto','Type'),
            'on_front' => Yii::t('auto','On Front'),
            'created_at' => Yii::t('auto','Created At'),
            'updated_at' => Yii::t('auto','Updated At'),
            'created_by' => Yii::t('auto','Created By'),
            'updated_by' => Yii::t('auto','Updated By'),
            'is_api' => Yii::t('auto','Is Api'),
            'frontImage' => Yii::t('auto','Front Image'),
        ];
    }

    public function getVehicle()
    {
        return $this->hasOne(Vehicle::class,['id' => 'vehicle_id']);
    }

    public function getImageFullPath($options=[]){
        $path = ((strpos($this->path, '/') === 0) ? '' : '/').$this->path .".".$this->extension;
        $height = 'auto';
        $width = 'auto';
        $quality = 'auto';
        //tr,w-1600,h-900,q-auto
        if(!empty($options['resolution'])){
            $resolution = explode('x', $options['resolution']);
            $width = $resolution[0];
            $height = $resolution[1];
        }
        if(!empty($options['quality'])){
            $quality = $options['quality'];
        }
        $path = "tr,w-{$width},h-{$height},q-{$quality}".$path;
        return Yii::$app->params['cdnUrl']."/".Yii::getAlias($path);



        if(strpos($this->path, '/front-images/') !== false){
            $path = $this->path .'.'.$this->extension;
            if(!empty($options['resolution'])){
                $path = $this->path ."-{$options['resolution']}.".$this->extension;
            }
            return Yii::$app->params['adminUrl'].Yii::getAlias($path);
        }
        if(strpos($this->path, '/car-listing/') !== false){
            return Yii::$app->params['frontendUrl'].Yii::getAlias($this->path .'.'.$this->extension);
        }

        return Yii::getAlias($this->path .'.'.$this->extension);
    }


    public function getAttachmentFullPath($options=[]){
        $path = ((strpos($this->path, '/') === 0) ? '' : '/').$this->path .".".$this->extension;
        $baseUrl = (strpos($path, '/attachment/') === false) ? Yii::$app->params['adminUrl'] : Yii::$app->params['frontendUrl'];
        return $baseUrl."".Yii::getAlias($path);
    }

    public function afterSave($insert, $changedAttributes)
    {
        $this->vehicle->image_counter = VehicleImages::find()->where(['vehicle_id' => $this->vehicle_id])->count();
        $this->vehicle->save();
        parent::afterSave($insert, $changedAttributes); // TODO: Change the autogenerated stub
    }

    public function removeCdnCache(){
        $cdnCacheFolderPath = $this->getCdnAppBasePath();
        $cdnCacheFolderPathInfo = pathinfo($cdnCacheFolderPath);
        $directories = glob($cdnCacheFolderPathInfo['dirname'] . '/*' , GLOB_ONLYDIR);
        foreach ($directories as $directory){
            $dirFilePath = $directory."/".$cdnCacheFolderPathInfo['basename'];
            if(is_dir($directory) && file_exists($dirFilePath)){
                @unlink($dirFilePath);
            }
        }
    }
    private function getCdnAppBasePath (){

        $mainFolder = '';
        if(strpos($this->path, '/front-images/') !== false){
            $mainFolder = 'backend';
        }else
            if(strpos($this->path, '/car-listing/') !== false){
                $mainFolder = 'frontend';
            }
        $filePath = $this->path.".".$this->extension;
        $cdnAppBasePath = Yii::$app->basePath . '/../frontend/web/cdn-images/'.$mainFolder.'/web'.$filePath;

        return $cdnAppBasePath;
    }
}
