<?php

namespace common\models\search;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use common\models\Payments;

/**
 * PaymentsSearch represents the model behind the search form about `common\models\Payments`.
 */
class PaymentsSearch extends Payments
{
    public $created_operand;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id'], 'integer'],
            [['created' ,'created_operand', 'payment_type', 'ref_id', 'ref_product', 'payment_status', 'payer_mail', 'transaction_id'], 'safe'],
            [['amount', 'transaction_fee'], 'number'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Payments::find();

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => Yii::$app->request->cookies->getValue('_grid_page_size', 20),
            ],
            'sort' => [
                'defaultOrder' => [
                    'id' => SORT_DESC,
                ],
            ],
        ]);

        $this->load($params);

//        if (!$this->validate()) {
//            // uncomment the following line if you do not want to return any records when validation fails
//            // $query->where('0=1');
//            return $dataProvider;
//        }

        $query->andFilterWhere([
            'id' => $this->id,
            'amount' => $this->amount,
            'transaction_fee' => $this->transaction_fee,
        ]);

        $query->andFilterWhere([($this->created_operand) ? $this->created_operand : '=', 'created', ($this->created) ? strtotime($this->created) : null]);

        $query->andFilterWhere(['like', 'payment_type', $this->payment_type])
            ->andFilterWhere(['like', 'ref_id', $this->ref_id])
            ->andFilterWhere(['like', 'ref_product', $this->ref_product])
            ->andFilterWhere(['like', 'payment_status', $this->payment_status])
            ->andFilterWhere(['like', 'payer_mail', $this->payer_mail])
            ->andFilterWhere(['like', 'transaction_id', $this->transaction_id]);
//        echo $query->createCommand()->rawSql;
        return $dataProvider;
    }
}
