<?php

namespace frontend\controllers;

use backend\modules\vehicle\models\Owner;
use common\helpers\FacebookManager;
use common\helpers\NotificationsHelper;
use common\models\FavoriteVehicle;
use common\models\Images360;
use common\models\LanguageSource;
use common\models\LanguageTranslate;
use common\models\NewsletterClientList;
use common\models\Notifications;
use common\models\VehicleBidsSearch;
use common\models\VehicleLang;
use common\models\VehicleSearch;
use frontend\models\ChangePasswordForm;
use frontend\models\ResendVerificationEmailForm;
use frontend\models\VerifyEmailForm;
use yii\base\DynamicModel;
use yii\db\Exception;
use yii\db\Expression;
use yii\helpers\ArrayHelper;
use yii\helpers\FileHelper;
use yii\helpers\Url;
use yii\helpers\Json;
use yii\helpers\BaseJson;
use yii\web\Response;
use yii\widgets\ActiveForm;
use yii\helpers\Inflector;
use yii\web\Cookie;
use Yii;
use yii\base\InvalidArgumentException;
use yii\web\BadRequestHttpException;
use yii\web\Controller;
use yii\filters\VerbFilter;
use yii\filters\AccessControl;
use common\models\LoginFormF;
use frontend\models\PasswordResetRequestForm;
use frontend\models\TransactionFrom;
use frontend\models\ResetPasswordForm;
use frontend\models\SignupForm;
use frontend\models\DealersignupForm;
use frontend\models\ContactForm;
use yii\web\NotFoundHttpException;
use yii\web\UploadedFile;
use common\models\Users;
// use common\models\DealerUsers;
use common\models\User;
use common\models\Role;
use common\models\Vehicle;
use common\models\DropdownList;
use common\models\DropdownListLang;
use common\models\VehicleEquipment;
use common\models\VehicleRemark;
use common\models\VehicleImages;
use common\models\ListingStepSearch;
use common\models\VehicleBids;
use yii\data\ActiveDataProvider;
use frontend\models\MessageFrom;
use frontend\models\GroupmessageFrom;
use frontend\models\CalenderFrom;
/**
 * Site controller
 */
class SiteController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'only' => ['logout','car-detail','favourite-listing','favourite','my-listing','listing','edit-profile','profile','notifications','image-upload','change-password'],
                'rules' => [
                    [
                        'actions' => ['logout','car-detail','favourite-listing','favourite','my-listing','listing','edit-profile','profile','notifications','image-upload','change-password', 'vehicle-appointment-slots'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
            'captcha' => [
                'class' => 'yii\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
            'auth' => [
                'class' => 'yii\authclient\AuthAction',
                'successCallback' => [$this, 'oAuthSuccess'],
            ],
        ];
    }

    /**
     * Logs in a user.
     *
     * @return mixed
     */

    public function beforeAction($action)
    {
        if ($action->id == 'language') {
            $this->enableCsrfValidation = false;
        }
        return parent::beforeAction($action);
    }

    public function actionLanguages($lang)
    {
        Yii::$app->language = $lang;
        $languageCookie = new Cookie([
            'name' => 'language',
            'value' => $lang,
            'expire' => time() + 60 * 60 * 24 * 30, // 30 days
        ]);

        Yii::$app->response->cookies->add($languageCookie);
        return $this->redirect(Yii::$app->request->referrer);
    }

    /**
     * Displays homepage.
     *
     * @return mixed
     */
    public function actionIndex()
    {

        $searchModel = new VehicleSearch();
        $dataProvider = $searchModel->search($this->request->queryParams);
        $model = new ContactForm();
        $list_lang = new DropdownListLang();
        return $this->render('index',[
            'list_lang' => $list_lang,
            'dataProvider' => $dataProvider,
            'model' => $model,
            'searchModel' => $searchModel,
        ]);
    }

    /**
     *  my listing page.
     *
     * @return mixed
     */
    public function actionFavouriteListing()
    {
        $vehicle = Vehicle::find()->where(['approved_at' => Vehicle::PUBLISHED]);
        $model = FavoriteVehicle::find()
            ->innerJoinWith('vehicle')
            ->where(['favorite_vehicle.user_id' => Yii::$app->user->identity->id]);
        $dataProvider = new ActiveDataProvider([
            'query' => $model,
            'pagination' => false,
        ]) ;
        return $this->render('favourite-listing',[
            'dataProvider' => $dataProvider,
            'vehicle' => $vehicle,
            'model' => $model,
        ]);
    }

    public function actionMyBiddings()
    {
        $model = new VehicleBids();
        $dataProvider = new ActiveDataProvider([
            'query' => VehicleBids::find()->innerJoinWith('vehicle'),
        ]);

        $dataProvider->query->where(['vehicle_bids.user_id' => Yii::$app->user->identity->id]);
        $searchModel = new VehicleBidsSearch();

        $vehicle = Vehicle::find()->where(['is_sold' => Vehicle::IS_SOLD]);

        $total_bids = VehicleBids::find()->where(['user_id' => Yii::$app->user->identity->id])->count();

        $successful_bids = VehicleBids::find()->where(['vehicle_id' => $model->getSoldVehicle(), 'user_id' => Yii::$app->user->identity->id])->count();

        $active_bids = VehicleBids::find()->where(['vehicle_id' => $model->getVehicles(), 'user_id' => Yii::$app->user->identity->id])->count();

        return $this->render('my-biding',[
            'model' => $model,
            'dataProvider' => $dataProvider,
            'searchModel' => $searchModel,
            'total_bids' => $total_bids,
            'successful_bids' => $successful_bids,
            'active_bids' => $active_bids,
        ]);
    }

    public function actionSuccessfulBiding()
    {
        $model = new VehicleBids();
        $dataProvider = new ActiveDataProvider([
            'query' => VehicleBids::find(),
        ]);
        $dataProvider->query->where(['user_id' => Yii::$app->user->identity->id]);
        $searchModel = new VehicleBidsSearch();
        return $this->render('successful-biding',[
            'model' => $model,
            'dataProvider' => $dataProvider,
            'searchModel' => $searchModel,
        ]);
    }

    public function actionActiveBiding()
    {
        $model = new VehicleBids();
        $dataProvider = new ActiveDataProvider([
            'query' => VehicleBids::find(),
        ]);
        $dataProvider->query->where(['user_id' => Yii::$app->user->identity->id]);
        $searchModel = new VehicleBidsSearch();
        return $this->render('active-biding',[
            'model' => $model,
            'dataProvider' => $dataProvider,
            'searchModel' => $searchModel,
        ]);
    }

    /**
     *  my listing page.
     *
     * @return mixed
     */
    public function actionMyListing()
    {
        $model = Vehicle::find()->where(['user_id' => Yii::$app->user->identity->id]);
        $dataProvider = new ActiveDataProvider([
            'query' => $model,
            'pagination' => false,
        ]) ;
        return $this->render('my-listing',[
            'dataProvider' => $dataProvider,
            'model' => $model,
        ]);
    }


    /**
     *  paid car form page.
     *
     * @return mixed
     */
    public function actionEditListing($slug)
    {
        $model = Vehicle::findOne(['slug'=> $slug]);
        $image = VehicleImages::findOne(['vehicle_id' => $model->id, 'type' => VehicleImages::TYPE_TWO]);
        $equipment = ArrayHelper::getColumn(VehicleEquipment::find()->where(['vehicle_id'=> $model->id])->all(),'equipment_id');
        $list = new DropdownListLang();
        $vehicle_lang = new VehicleLang();
        $model->equipment = $equipment;
        $infection = null;
        if ($image) {
            $infection = $image->path;
        }

        if ($model->load(Yii::$app->request->post()) && $model->save(false)) {
        if($image){
            $infection_doc = UploadedFile::getInstance($image,'path');

            if ($infection_doc) {
                $image->path = Yii::$app->security->generateRandomString(12).'.'.$infection_doc->extension;
            }else {
                $image->path = $infection;
            }

            if ($image->save(false)) {
                if ($infection_doc) {
                    $infection_doc->saveAs('uploads/attachment/'.$image->path);
                }
                Yii::$app->session->setFlash('success',Yii::t('auto','Data Infomation Updated SuccessFully !'));
                return $this->redirect(['site/update-image','id' => $model->id]);
            }
        }
            }
        return $this->render('edit-listing',[
            'model' => $model,
            'list' => $list,
            'vehicle_lang' => $vehicle_lang
        ]);
    }

    /**
     * @param $id
     * @return mixed
     */
    public function actionUpdateImage($id)
    {
        $model = new VehicleImages();
        $vehicle = VehicleImages::find()->where(['vehicle_id' => $id])->all();
        $frontImage = Vehicle::findOne(['id' => $id]);

        return $this->render('image-upload',
            [
                'vehicle' => $vehicle,
                'model' => $model]);
    }

    /**
     *  paid car page.
     *
     * @return mixed
     */
    public function actionStepToListing($slug)
    {

        if ($slug == Vehicle::VEHICLE_FREE){

            return $this->render('sell-car');

        }elseif ($slug == Vehicle::VEHICLE_FAST) {

            return $this->render('fast-sell');

        }elseif ($slug == Vehicle::VEHICLE_ROUND) {

            return $this->render('paid-car');

        }else{
            return $this->goHome();
        }
    }

    /**
     * @return mixed
     */
    public function actionSellYourCar()
    {
        $vehicle_image = new VehicleImages();
        $dataProvider = new ActiveDataProvider([
            'query' => Vehicle::find()->where(['status' => Vehicle::PUBLISHED  ]),
        ]);
        return $this->render('sell-your-car',[
            'dataProvider' => $dataProvider,
            'vehicle_image' => $vehicle_image,
        ]);
    }

    public function actionTest($slug)
    {
        $drop_lang = new DropdownListLang();
        $model = Vehicle::findOne(['slug' => $slug]);
        $user = User::findOne(['id' => $model->user_id]);
        $image = VehicleImages::find()->where(['vehicle_id' => $model->id,'type' => VehicleImages::TYPE_ONE])->all();
        $attachment = VehicleImages::findOne(['vehicle_id' => $model->id,'type' => VehicleImages::TYPE_TWO]);
        $image_chunk = array_chunk($image,5);
        $equipment = VehicleEquipment::find()->where(['vehicle_id' => $model->id])->all();
        $remark = VehicleRemark::find()->where(['vehicle_id' => $model->id])->all();
        $image_data  = Images360::findAll(['vehicle_id'=>$model->id]);
        $ext = Images360::findOne(['vehicle_id'=>$model->id]);
        $count = Images360::find()->where(['vehicle_id'=>$model->id])->count();

        return $this->render('test',[
            'drop_lang' => $drop_lang,
            'model' => $model,
            'user' => $user,
            'image' => $image,
            'image_chunk' => $image_chunk,
            'equipment' => $equipment,
            'remark' => $remark,
            'attachment' =>$attachment

        ]);
    }

    public function actionSearch() {
        if(empty($this->request->queryParams['car_type']) || !in_array($this->request->queryParams['car_type'], [1,2,3])){
            return $this->redirect(['/site/search','keyword'=>'','car_type'=>1]);
        }
        $searchModel = new VehicleSearch();
        $vehicle_title = new VehicleLang();
        // $models = Vehicle::find()->where(['approved_at' => Vehicle::PUBLISHED]);
      $query	=(new \yii\db\Query())->select(['vehicle.*','users.*'])
        ->from('vehicle')
        ->join(	'JOIN',
            'users',
            'users.id = vehicle.user_id'
        )->where(['vehicle.status' => Vehicle::PUBLISHED]); ;
          $command = $query->createCommand();
         $models = $command->queryAll();

        $list = new DropdownListLang();
        $dataProvider = $searchModel->search($this->request->queryParams);

        return $this->render('search',[
            'models' => $models,
            'list' => $list,
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'vehicle_title' => $vehicle_title,
        ]);
    }

    public function actionSearchByKeyword($term) {
        \Yii::$app->response->format = \yii\web\Response::FORMAT_JSON;
        //$lng = Yii::$app->language;
        $term = trim($term);
        $query	=(new \yii\db\Query())
            ->select('vehicle_lang.title')->distinct()
            ->from('vehicle')
            ->join(	'JOIN',
                'vehicle_lang',
                'vehicle.id = vehicle_lang.parent_id'
            )->distinct()
            ->where(['vehicle.status' => Vehicle::PUBLISHED])
            ->andWhere(['like', 'vehicle_lang.title', $term])
            ->andWhere(['in', 'vehicle.car_type', [Vehicle::CAR_TYPE_FREE,  Vehicle::CAR_TYPE_ROUND]]);
        $command = $query->createCommand();
        $data = $command->queryAll();
        $response = [];
        foreach ($data as $index => $item) {
            $response[] = [
                'id' => '',
                'label' => $item['title'],
                'value' => $item['title'],
            ];
        }
        return $response;

    }

    public function actionGetManufacturerModel(){
        Yii::$app->response->format = \yii\web\Response::FORMAT_JSON;
        $post = Yii::$app->request->post();


        $manufacturer_id = (isset($post['depdrop_all_params']['manufacturer_id'])) ? $post['depdrop_all_params']['manufacturer_id'] : '';
        $response = [
            'output' => [],
            'selected' => ''
        ];
        if (!empty($manufacturer_id)) {
            $lang = \Yii::$app->language;
            $list = \yii\helpers\ArrayHelper::map(Yii::$app->db->createCommand("SELECT DF.id, DS.title from dropdown_list DF, dropdown_list_lang DS WHERE DF.id = DS.parent_id and DF.parent_id = '$manufacturer_id' and DF.category  = 'VehicleModelManufacturer' and DS.language = '$lang' ORDER BY 
                                                        CASE 
                                                            WHEN DS.title = 'Other'
                                                            THEN 1
                                                            ELSE 0
                                                        END ASC
                                                     , DS.title ASC  ")->queryAll(), 'id', 'title');
            $listDepDrop = [];
            array_walk($list, function($value, $k)use(&$listDepDrop){ $listDepDrop[] = [
                'id' => $k,
                'name' => $value,
            ]; });
            $response['output'] = $listDepDrop;
        }
        return $response;
    }

    public function actionScan()
    {
        $model = LanguageSource::find()->all();

        foreach ($model as $item) {
            $tr = new LanguageTranslate();

            $tr->id = $item->id;
            $tr->language = 'ar-Ar';
            $tr->translation = 'اختبار النص هنا';
            $tr->save();
        }
    }

    public function actionVehicleScan()
    {
        $model = VehicleLang::find()->where(['language' => 'en'])->all();

        foreach ($model as $item) {
            $tr = new VehicleLang();

            $tr->parent_id = $item->parent_id;
            $tr->language = 'ar';
            $tr->title = 'اختبار النص هنا :-23اختبار النص هنا';
            $tr->save();
        }
    }

    public function actionEditProfile()
    {
        $document = null;
        $profile = null;

        $id = Yii::$app->user->identity->id;
        $model = $this->findUser($id);

        $changePasswordForm = new ChangePasswordForm();
        if ($model->document)
        {
            $document = $model->document;
        }

        if ($model->profile_image)
        {
            $profile = $model->profile_image;
        }
        if ($model->load(Yii::$app->request->post())){

            $doc = UploadedFile::getInstance($model,'document');
            $pro = UploadedFile::getInstance($model,'profile_image');

            if ($doc) {
                $model->document = Yii::$app->security->generateRandomString(12)
                    .'.'.$doc->extension;
            }else{
                $model->document = $document;
            }

            if ($pro) {
                $model->profile_image = $model->name.'.'.Yii::$app->security->generateRandomString(12).'.'.$pro->extension;
            }else{
                $model->profile_image = $profile;
            }

            if ($model->save(false)) {
                if ($doc){
                    $doc->saveAs('uploads/document/'.$model->document);
                }
                if ($pro){
                    $pro->saveAs('uploads/profile/'.$model->profile_image);
                }
                Yii::$app->session->setFlash('success', Yii::t('auto','Profile has been updated successfully'));
                return $this->render("profile",[
                    'model'=>$model,
                    'changePasswordForm' => $changePasswordForm,
                    'active'=>'edit-profile',
                ]);
            }
        }
        return $this->render('profile',[
            'model' => $model,
            'changePasswordForm' => $changePasswordForm,
            'active'=>'edit-profile',
        ]);
    }

    /**
     *  paid car form page.
     *
     * @return mixed
     */

    public function actionListing($slug) {
        $path = __DIR__ . '/../web/uploads/attachment';
        if(!is_dir($path)){
            FileHelper::createDirectory($path, $mode = 0777, $recursive = true);
        }

        $path = __DIR__ . '/../web/uploads/car-listing';
        if(!is_dir($path)){
            FileHelper::createDirectory($path, $mode = 0777, $recursive = true);
        }

        $model = new Vehicle();
        if ($slug == Vehicle::VEHICLE_FREE) {
            $model->vehicle_type = Vehicle::FREE;
            $model->car_type = Vehicle::CAR_TYPE_FREE;
            // $model->approved_at = Vehicle::PUBLISHED;
        }

        if ($slug == Vehicle::VEHICLE_FAST) {
            $model->vehicle_type = Vehicle::FAST;
            $model->car_type = Vehicle::CAR_TYPE_FAST;
            // $model->approved_at = Vehicle::NOT_PUBLISHED;
        }

        if ($slug == Vehicle::VEHICLE_ROUND) {
            $model->image360 = Vehicle::YES;
            $model->vehicle_type = Vehicle::ROUND;
            // $model->approved_at = Vehicle::NOT_PUBLISHED;
            $model->status = Vehicle::PENDING;
            $model->car_type = Vehicle::CAR_TYPE_ROUND;
        }


        $vehicle_image = new VehicleImages();
        $list = new DropdownListLang();
        $vehicle_lang = new VehicleLang();



        if($user = Users::findOne(Yii::$app->user->identity->id)){
            $model->full_name = $user->name;
            $model->email = $user->email;
            $model->phone_number = $user->phone;
        }

        if ($model->load(Yii::$app->request->post())) {
            $model->slug = Inflector::slug($model->title.'-'.Yii::$app->security->generateRandomString(12));
            $model->user_id = Yii::$app->user->identity->id;
            $model->owner_id = Yii::$app->user->identity->owner_id;

            /*
             * Owner Type ID
             * */
            $ownerTypeName = (Yii::$app->user->identity->type == Users::OWNER) ? 'Private Owner' : 'Showrooms';

            $ownerTypeNameData = DropdownListLang::findOne(['title' => $ownerTypeName, 'language' => 'en-US']);
            if(!empty($ownerTypeNameData)){
                $model->owner_type_id = $ownerTypeNameData->parent_id;
            }

            $model->approved_at = Vehicle::NOT_PUBLISHED;
            $model->created_at = time();
            $model->created_by = Yii::$app->user->identity->id;

            $model->vehicle_type = Vehicle::VEHICLE_TYPE_USER_CARS_FOR_SALE;
            if ($slug == Vehicle::VEHICLE_FREE) {
                //$model->vehicle_type = Vehicle::FREE;

                $model->car_type = Vehicle::CAR_TYPE_FREE;
                // $model->approved_at = Vehicle::PUBLISHED;
            }

            if ($slug == Vehicle::VEHICLE_FAST) {
                //$model->vehicle_type = Vehicle::FAST;
                $model->car_type = Vehicle::CAR_TYPE_FAST;
                // $model->approved_at = Vehicle::NOT_PUBLISHED;
            }

            if ($slug == Vehicle::VEHICLE_ROUND) {
                $model->image360 = Vehicle::YES;
                //$model->vehicle_type = Vehicle::ROUND;
                // $model->approved_at = Vehicle::NOT_PUBLISHED;
                $model->status = Vehicle::PENDING;
                $model->car_type = Vehicle::CAR_TYPE_ROUND;
            }

            $attachment2 = UploadedFile::getInstance($model,'attachment');
            if ($slug == Vehicle::VEHICLE_FAST) {
                if(!$attachment2){
                    Yii::$app->session->setFlash('danger',Yii::t('auto', 'Inspection Report Is Required'));
                    return $this->refresh();
                }
            }

            if ($model->save(false)) {

                /*
                 * Update contact number of user
                 * */
                if(empty($user->phone)){
                    $user->phone = $model->phone_number;
                    $user->save(false);
                }

                $attachment = UploadedFile::getInstance($model,'attachment');
                if($attachment){
                    $filepathString=Yii::$app->security->generateRandomString(12);
                    $model->attachment = Yii::$app->params['frontendUrl'].'/uploads/attachment/'.$filepathString;
                    $vehicle_image->vehicle_id = $model->id;
                    $vehicle_image->path = $model->attachment;
                    $vehicle_image->extension = $attachment->extension;
                    $vehicle_image->type = VehicleImages::TYPE_TWO;
                    $vehicle_image->created_by = Yii::$app->user->identity->id;

                    if ($vehicle_image->save(false)) {
                        $attachment->saveAs('uploads/attachment/'.$filepathString.'.'.$attachment->extension);
                        $vehicle_image->removeCdnCache();
                        Yii::$app->session->set('listing_id', $model->id);

                    }
                }

                $vehicle_lang->parent_id = $model->id;
                $vehicle_lang->language = Vehicle::ENGLISH_LANGUAGE;
                $vehicle_lang->title = $model->title;
                $vehicle_lang->save();

                $vehicle_lang = new VehicleLang();
                $vehicle_lang->parent_id = $model->id;
                $vehicle_lang->language = Yii::$app->language;
                $vehicle_lang->title = $model->title;
                $vehicle_lang->save();

                if ($model->equipment && $model->validate(false)) {

                    foreach ($model->equipment as $equipment) {
                        $equip = new VehicleEquipment();

                        $equip->vehicle_id = $model->id;
                        $equip->equipment_id = $equipment;
                        $equip->save();
                    }
                }
                if ($model->remark && $model->validate(false)) {

                    foreach ($model->remark as $remarks) {
                        $remark = new VehicleRemark();

                        $remark->vehicle_id = $model->id;
                        $remark->remark_id = $remarks;
                        $remark->save();
                    }
                }

                // if ($model->has_carseer_report == Vehicle::NO) {
                //     return $this->redirect(['buy-carseer-report','id'=>$model->id]);
                // }

                // $getdata= Yii::$app->request->post();
                // if(isset($getdata['datetimes'])){
                //     $datetime = $getdata['datetimes'];
                //     $split = explode('-',$datetime);
                //     $converttime = strtotime($split[0]);
                //     $calender = new CalenderFrom();
                //     $calender->user_id=Yii::$app->user->identity->id;
                //     $calender->vehicle_id= $model->id;
                //     $calender->date_time_from=strtotime($split[0]);
                //     $calender->date_time_to=strtotime($split[1]);
                //     $calender->created_at=time();
                //     $calender->updated_at=time();
                //     $calender->save();
                // }

                if ($vehicle_image->load(Yii::$app->request->post())) {
                    $vehicle_image->path = UploadedFile::getInstances($vehicle_image, 'path');

                    if ($vehicle_image->path && $vehicle_image->validate(false)) {
                        foreach ($vehicle_image->path as $path) {
                            $filestring= Yii::$app->security->generateRandomString(12);
                            $upload = new VehicleImages();
                            $upload->vehicle_id = $model->id;
                            $upload->path = '/uploads/car-listing/'.$filestring;
                            $upload->extension = $path->extension;
                            $upload->type = VehicleImages::TYPE_ONE;
                            $upload->created_at = date('Y-m-d:H:i');
                            $upload->created_by = Yii::$app->user->identity->id;
                            if ($upload->save(false)) {
                                $path->saveAs('uploads/car-listing/' . $filestring.'.'. $path->extension);
                                $upload->removeCdnCache();
                            }
                        }
                    }
                }

                return $this->redirect(['step-2-listing','id'=>$model->id]);

            } else {

                Yii::$app->session->setFlash('danger','Something Went Wrong Please try Again Later !');
                return $this->refresh();
            }

        }
        return $this->render('listing',[
            'model' => $model,
            'list' => $list,
            'vehicle_lang' => $vehicle_lang,
            'vehicle_image' => $vehicle_image,
            'slug'=>$slug,
        ]);
    }

    private  function getBetweenDates($startDate, $endDate)
    {
        $rangArray = [];

        $startDate = strtotime($startDate);
        $endDate = strtotime($endDate);

        for ($currentDate = $startDate; $currentDate <= $endDate;
             $currentDate += (86400)) {

            $date = Yii::t('auto', date('D', $currentDate))."<br />". Yii::t('auto', date('M', $currentDate))." ". date('d', $currentDate);
            $rangArrayTmp = [];
            $rangArrayTmp['day_with_name'] = $date;
            $rangArrayTmp['day_with_date'] = date('Y-m-d', $currentDate);
            //$rangArrayTmp['day_with_date_2'] = date('d M, Y', $currentDate);
            $rangArrayTmp['day_with_date_2'] = Yii::t('auto', date('d', $currentDate))." ".Yii::t('auto', date('M', $currentDate)).", ".Yii::t('auto', date('Y', $currentDate));
            $rangArray[] = $rangArrayTmp;
        }

        return $rangArray;
    }

    private function timeslots($duration, $cleanup, $start, $end){
        $start = new \DateTime($start);
        $end = new \DateTime($end);
        $interval = new \DateInterval("PT".$duration."M");
        $cleanupInterval = new \DateInterval("PT".$cleanup."M");
        $slots = array();

        for($intStart = $start; $intStart<=$end; $intStart->add($interval)->add($cleanupInterval)){
            $endPeriod = clone $intStart;
            $endPeriod->add($interval);
            if($endPeriod>$end){
                /*$slots[] = [
                    'time_am_pm' => $intStart->format("h:i A"),
                    'time_24' => $intStart->format("H:i"),
                ];*/
                break;
            }

            //$slots[] = $intStart->format("H:iA")." - ". $endPeriod->format("H:iA");
            $slots[] = [
                'time_am_pm_label_v2' => (Yii::t('auto', $intStart->format("h")).":".Yii::t('auto', $intStart->format("i"))." ".Yii::t('auto', $intStart->format("A")))
                                            ." - ".
                    (Yii::t('auto', $endPeriod->format("h")).":".Yii::t('auto', $endPeriod->format("i"))." ".Yii::t('auto', $endPeriod->format("A"))),
                'time_am_pm_label' => $intStart->format("h:i A")." - ". $endPeriod->format("h:i A"),
                'time_start_am_pm' => $intStart->format("h:i A"),
                'time_start_24' => $intStart->format("H:i"),
                'time_end_am_pm' => $endPeriod->format("h:i A"),
                'time_end_24' => $endPeriod->format("H:i"),
            ];

        }

        return $slots;
    }

    private function getAppointmentCalendarValues($dayNum=0,$totalDays=5){

        $startDate = date('Y-m-d', strtotime((date('Y-m-d'))." +".($dayNum)." days"));
        $endDate = date('Y-m-d', strtotime($startDate." +".($totalDays-1)." days"));
        $days = $this->getBetweenDates($startDate, $endDate);
        $timeslots = $this->timeslots(30, 0, "09:00", "17:00");

        return [
            'days' =>  $days,
            'timeslots' =>  $timeslots,
            'totalDays' =>  $totalDays,
            'dayNum' =>  $dayNum,
            'duration' =>  30,
        ] ;
    }

    public function actionVehicleAppointmentSlots(){
        if (Yii::$app->request->getIsAjax()){
            Yii::$app->response->format = Response::FORMAT_JSON;
            $postData = Yii::$app->request->post();
            $model = Vehicle::findOne(['id' => $postData['vehicleId']]);
            $appointmentCalendarData = $this->getAppointmentCalendarValues($postData['dayNum']);
            $datesHtml = $this->renderPartial('_appointment_booking_slots_header', [
                'model' => $model,
                'appointmentCalendarData' => $appointmentCalendarData,
            ]);
            $slotsHtml = $this->renderPartial('_appointment_booking_slots_body', [
                'model' => $model,
                'appointmentCalendarData' => $appointmentCalendarData,
                'preSelectedDate' => !empty($postData['preSelectedDate']) ? $postData['preSelectedDate'] : '',

            ]);

            return [
                'status' => 1,
                'slotsHtml' => $slotsHtml,
                'datesHtml' => $datesHtml,
            ];


        }


    }

    public function actionBuyCarseerReportForOto(){
        if (!Yii::$app->request->isAjax) {
            return '';
        }
        Yii::$app->response->format = Response::FORMAT_JSON;
        try {
            $vinModel = new DynamicModel(['vin_number', 'vehicle_id']);
            $vinModel->addRule(['vin_number', 'vehicle_id'], 'required');
            if($vinModel->load(Yii::$app->request->post()) && $vinModel->validate(Yii::$app->request->post())){
                $lang = Yii::$app->params['short_language'];
                $get_report_from_vin = "https://api.carseer.com/query?vin={$vinModel->vin_number}&lang=$lang";
                $response_create_report = $this->curlRequest($get_report_from_vin);
                if(!empty($response_create_report) && $response_create_report['Message']=='HAS_DATA') {
                    $payableCharges = $response_create_report['Products'][0]['Price'] + Yii::$app->params['carseer_report'];

                    $data=[];
                    if(Yii::$app->user->isGuest){
                        throw new \Exception('Please login to continue.');
                    }
                    $user = Users::findOne(['id' => Yii::$app->user->identity->id]);
                    $name = $user->name;
                    $phone = $user->phone;
                    $email = $user->email;

                    $APIKey = Yii::$app->params['payment']['api_key'];
                    $MerchantID = Yii::$app->params['payment']['merchant_id'];
                    $ref = time();
                    $CurrencyCode= 'USD';
                    $redirect_url = Yii::$app->urlManager->createAbsoluteUrl(['site/callback-buy-carseer-report-for-oto','id'=>$vinModel->vehicle_id,'vin_number'=>$vinModel->vin_number]);
                    $post_url = Yii::$app->urlManager->createAbsoluteUrl('/');
                    $curl = curl_init();
                    curl_setopt_array($curl, array(
                        CURLOPT_URL => Yii::$app->params['payment']['url'],
                        CURLOPT_RETURNTRANSFER => true,
                        CURLOPT_ENCODING => "",
                        CURLOPT_MAXREDIRS => 10,
                        CURLOPT_TIMEOUT => 30,
                        CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                        CURLOPT_CUSTOMREQUEST => "POST",
                        CURLOPT_POSTFIELDS => "{\"amount\":$payableCharges,\"currency\":\"$CurrencyCode\",\"threeDSecure\":true,\"save_card\":false,\"description\":\" Carseer Report Payment, Payment for the customer {$name}, Vehicle ID : {$vinModel->vehicle_id}\",\"statement_descriptor\":\"Carseer Report Payment\",\"reference\":{\"transaction\":\"txn_{$ref}\",\"order\":\"ord_{$ref}\"},\"receipt\":{\"email\":true,\"sms\":false},\"customer\":{\"first_name\":\"$name\",\"email\":\"$email\",\"phone\":{\"country_code\":\"965\",\"number\":\"$phone\"}},\"merchant\":{\"id\":\"$MerchantID\"},\"source\":{\"id\":\"src_all\"},\"post\":{\"url\":\"$post_url\"},\"redirect\":{\"url\":\"$redirect_url\"}}",
                        CURLOPT_HTTPHEADER => array(
                            "authorization: Bearer $APIKey",
                            "content-type: application/json"
                        ),
                    ));

                    $response = curl_exec($curl);
                    $err = curl_error($curl);
                    curl_close($curl);
                    if ($err) {
                        throw new \Exception(Yii::t('auto', 'Request failed while initializing the transaction request. Please try again.'));
                    } else {
                        $data = json_decode($response);
                        if(!empty($data) && isset($data->transaction)){
                            return [
                                'status' => 1,
                                'message' => 'Success',
                                'data' => [
                                    'content' => $this->renderPartial('buy-carseer-report-partials/popup-proceed-transaction', [
                                        'transactionData' =>  $data->transaction
                                    ])
                                ],
                            ];
                        }else{
                            throw new \Exception(Yii::t('auto', 'Request failed while initializing the transaction request. Please try again.'));
                        }
                    }
                } else {
                    throw new \Exception(Yii::t('auto', 'Invalid VIN number. Please try different one'));
                }
            }else{
                throw new \Exception(Yii::t('auto', 'Failed to process your request. Please try again'));
            }

        }catch (\Exception $e){
            return [
                'status' => 0,
                'message' => 'Failed',
                'data' => [
                    'content' => $this->renderPartial('buy-carseer-report-partials/popup-error', [
                        'errorMessage' => $e->getMessage().$e->getLine()
                    ])
                ],
            ];
        }



    }

    public function actionCallbackBuyCarseerReportForOto(){
        $responseModel = new DynamicModel(['id', 'vin_number', 'tap_id']);
        $responseModel->addRule(['id', 'vin_number', 'tap_id'], 'required');
        $data = [
            'DynamicModel' => Yii::$app->request->get()
        ];
        try {
            if($responseModel->load($data) && $responseModel->validate($data)){
                $APIKey = Yii::$app->params['payment']['api_key'];
                $curl = curl_init();
                curl_setopt_array($curl, array(
                    CURLOPT_URL => "https://api.tap.company/v2/charges/".$responseModel->tap_id,
                    CURLOPT_RETURNTRANSFER => true,
                    CURLOPT_ENCODING => "",
                    CURLOPT_MAXREDIRS => 10,
                    CURLOPT_TIMEOUT => 30,
                    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                    CURLOPT_CUSTOMREQUEST => "GET",
                    CURLOPT_POSTFIELDS => "{}",
                    CURLOPT_HTTPHEADER => array(
                        "authorization: Bearer $APIKey",
                        "content-type: application/json"
                    ),
                ));

                $response = curl_exec($curl);
                $err = curl_error($curl);
                curl_close($curl);
                if ($err) {
                    throw new \Exception(Yii::t('auto', 'Failed to verify your transaction. Please contact administrator'));
                } else {
                    $getchargestatus = json_decode($response);
                    if(empty($getchargestatus)){
                        throw new \Exception(Yii::t('auto', 'Failed to verify your transaction. Please contact administrator'));
                    }

                    $transacation = new TransactionFrom();
                    $transacation->reference_no= $getchargestatus->id;
                    $transacation->user_id=Yii::$app->user->identity->id;
                    $transacation->description = "{$getchargestatus->status}({$getchargestatus->response->code}) : {$getchargestatus->description}";
                    $transacation->payment_type=2;
                    $transacation->amount= $getchargestatus->amount;
                    $transacation->status= ($getchargestatus->response->code == '000') ? 1 : 0;
                    $transacation->vehicle_id=$responseModel->id;
                    $transacation->created_at=time();
                    $transacation->updated_at=time();
                    $transacation->save();
                }
                if($getchargestatus->response->code !== '000'){
                    throw new Exception(Yii::t('auto', "Your transaction was failed. Reason: ({reason})", [
                        'reason' => $getchargestatus->status
                    ]));
                }
                $lang = Yii::$app->params['short_language'];

                $get_report_from_vin = "https://api.carseer.com/query?vin={$responseModel->vin_number}&lang=$lang";
                $response_create_report = $this->curlRequest($get_report_from_vin);

                $serial_number = $response_create_report['Products'][0]['Serial'];
                $get_report_from_vin = "https://api.carseer.com/Fetch?serial=$serial_number&lang=$lang";
                $response_get_report = $this->curlRequest($get_report_from_vin);
                if ($response_get_report['Message'] == 'success') {

                    $vehicle = Vehicle::findOne($responseModel->id);
                    if(empty($vehicle)){
                        throw new Exception(Yii::t('auto', "Your transaction was successful, but failed to fetch carseer report. Reason: No vehicle found."));
                    }
                    $vehicle->carseer_url = $response_get_report['URL'];
                    $vehicle->has_carseer_report = 1;
                    $vehicle->save(false);
                    Yii::$app->session->setFlash('success', Yii::t('auto', "Your transaction was successful and you buyed the carseer report "));
                    return $this->redirect(['step-2-listing','id' => $responseModel->id]);
                } else {
                    throw new Exception(Yii::t('auto', "Your transaction was successful, but failed to fetch carseer report. Reason: Failed to fetch carseer report."));
                }
            }else{
                throw new \Exception(Yii::t('auto', 'Failed to verify your transaction. Please contact administrator'));
            }
        }catch (\Exception $e){
            Yii::$app->session->setFlash('danger', $e->getMessage());
            if(!empty($responseModel->id)){
                return $this->redirect(['step-2-listing','id' => $responseModel->id]);
            }else{
                return $this->redirect('/');
            }


        }



    }

    public function actionStep2Listing($id) {

        $model = Vehicle::findOne(['id' => $id]);
        // $model->scenario = 'check_vin';



        if ($model->load(Yii::$app->request->post())) {
            $getdata= Yii::$app->request->post();

            if(!empty($getdata['appointment_date'])){

               $datetimeFrom = "{$getdata['appointment_date']} {$getdata['appointment_time_fom']}";
               $datetimeTo = "{$getdata['appointment_date']} {$getdata['appointment_time_to']}";

               $calender = new CalenderFrom();
                $calender->user_id = Yii::$app->user->identity->id;
                $calender->vehicle_id = $model->id;
                $calender->date_time_from = strtotime($datetimeFrom);
                $calender->date_time_to = strtotime($datetimeTo);
                $calender->created_at = time();
                $calender->updated_at = time();
                $calender->save();

                $calender->sendEmailToNotifyAdmin();
            }

            $model->save(false);
            $model->sendEmailToNotifyAdmin();


            if($model->car_type == Vehicle::ROUND) {
                Yii::$app->session->setFlash('success_vehicle', Yii::t('auto','Thanks for your time! We will contact you soon'));
                if ($model->pay_360_online_fees == Vehicle::YES) {
                    return $this->redirect(Url::toRoute(['site/pay','id'=>$id]));
                } else {
                    return $this->redirect(['confirm-car-detail','id' => $id]);
                }

                // return $this->redirect(Url::toRoute(['site/pay','id'=>$id]));
            } else {
                Yii::$app->session->setFlash('success_vehicle', Yii::t('auto','Thank you! Your request will be revised and approved accordingly.'));
                return $this->redirect(['confirm-car-detail','id' => $id]);
            }
        }
        /*
         * Appointment
         * */
        $appointmentCalendarData = $this->getAppointmentCalendarValues();


       $model->has_carseer_report = (!empty($model->carseer_url)) ? 1 : null;
       return $this->render('step2listning',[
            'model' => $model,
            'appointmentCalendarData' => $appointmentCalendarData,
            // 'carseer_url' => $carseer_url
        ]);
    }

    private function actionStepBuyReport($id,$vin){
        $post_url = Yii::$app->urlManager->createAbsoluteUrl('/');

        $curl = curl_init();
        $model = Vehicle::findOne($id);

        $lang = Yii::$app->params['short_language'];

        $get_report_from_vin = "https://api.carseer.com/query?vin=$vin&lang=$lang";
        $response_create_report = $this->curlRequest($get_report_from_vin);
        $Total = $response_create_report['Products'][0]['Price'] + Yii::$app->params['carseer_report'];
        $data=[];
        $user = Users::findOne(['id' => Yii::$app->user->identity->id]);
        $name = $user->name;
        $phone = $user->phone;
        $email = $user->email;
        $APIKey = Yii::$app->params['payment']['api_key'];
        $MerchantID = Yii::$app->params['payment']['merchant_id'];
        $ref = time();
        $CurrencyCode= 'USD';
        $redirect_url = Yii::$app->urlManager->createAbsoluteUrl(['site/step-2-listing','id'=>$id,'vin'=>$vin]);

        curl_setopt_array($curl, array(
            CURLOPT_URL => Yii::$app->params['payment']['url'],
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => "{\"amount\":$Total,\"currency\":\"$CurrencyCode\",\"threeDSecure\":true,\"save_card\":false,\"description\":\" Payment for the customer {$name}, Vehicle ID : {$model->id}\",\"statement_descriptor\":\"Carseer Report Payment\",\"reference\":{\"transaction\":\"txn_{$ref}\",\"order\":\"ord_{$ref}\"},\"receipt\":{\"email\":true,\"sms\":false},\"customer\":{\"first_name\":\"$name\",\"email\":\"$email\",\"phone\":{\"country_code\":\"965\",\"number\":\"$phone\"}},\"merchant\":{\"id\":\"$MerchantID\"},\"source\":{\"id\":\"src_all\"},\"post\":{\"url\":\"$post_url\"},\"redirect\":{\"url\":\"$redirect_url\"}}",
            CURLOPT_HTTPHEADER => array(
                "authorization: Bearer $APIKey",
                "content-type: application/json"
            ),
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);

        curl_close($curl);


        if ($err) {
            echo "cURL Error #:" . $err;
        } else {
            $data = json_decode($response);
            // print_r( $data);die;
            return $this->redirect($data->transaction->url);

        }
        return $redirect_url;
    }

    public function actionBuyCarseerReport($id)
    {
        $model = Vehicle::findOne($id);
        $model->scenario = 'check_vin';

        if ($model->load(Yii::$app->request->post()) && $model->validate()) {
            $vin = $model->vin_number;
            $lang = Yii::$app->params['short_language'];
            $get_report_from_vin = "https://api.carseer.com/query?vin=$vin&lang=$lang";
            $response_create_report = $this->curlRequest($get_report_from_vin);

            if($response_create_report['Message']=='HAS_DATA') {
                $this->actionBuyReport($id,$vin);
            }else{
                $model->addError('vin_number','Incorrect Vin NUmber');
                $model->validate();
            }
        }
        return $this->render('buy-report',[
            'id' => $model->id,
            'model' => $model,
        ]);
    }

    public function actionSuccessCarseerReportGenerated($id,$vin,$tap_id)
    {

            $APIKey = Yii::$app->params['payment']['api_key'];
            // $APIKey='TDGTG@45GHJRTJNCVSRSDFGD@@TERAF';
            $curl = curl_init();
            curl_setopt_array($curl, array(
            CURLOPT_URL => "https://api.tap.company/v2/charges/".$tap_id,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "GET",
            CURLOPT_POSTFIELDS => "{}",
            CURLOPT_HTTPHEADER => array(
                "authorization: Bearer $APIKey",
                "content-type: application/json"
            ),
            ));

            $response = curl_exec($curl);
            $err = curl_error($curl);

            curl_close($curl);

            if ($err) {
            echo "cURL Error #:" . $err;
            } else {
                $getchargestatus = json_decode($response);
                $transacation = new TransactionFrom();
                $transacation->reference_no= $getchargestatus->id;
                $transacation->user_id=Yii::$app->user->identity->id;
                $transacation->description='carseer report fee';
                $transacation->payment_type=2;
                $transacation->amount= $getchargestatus->amount;
                $transacation->vehicle_id=$id;
                $transacation->created_at=time();
                $transacation->updated_at=time();
                $transacation->save();
            }

        $model = Vehicle::findOne($id);
        $model->scenario = 'check_vin';

        $lang = Yii::$app->params['short_language'];

        $get_report_from_vin = "https://api.carseer.com/query?vin=$vin&lang=$lang";
        $response_create_report = $this->curlRequest($get_report_from_vin);

        $serial_number = $response_create_report['Products'][0]['Serial'];
        $get_report_from_vin = "https://api.carseer.com/Fetch?serial=$serial_number&lang=$lang";
        $response_get_report = $this->curlRequest($get_report_from_vin);


        if ($response_get_report['Message'] == 'success') {
            $model->carseer_url = $response_get_report['URL'];
            if ($model->save(false)){
                Yii::$app->session->setFlash('success', 'Vin Number Check SuccessFully !');
                return $this->redirect(['image-upload','id'=>$model->id]);
            }

        } else {
            Yii::$app->session->setFlash('danger', 'Data Check Successfully');
            return $this->redirect(['buy-carseer-report','id'=>$model->id]);
        }
    }

    public function actionBuyReport($id,$vin)
    {

        $post_url = Yii::$app->urlManager->createAbsoluteUrl('/');

        $curl = curl_init();
        $model = Vehicle::findOne($id);

        $lang = Yii::$app->params['short_language'];

        $get_report_from_vin = "https://api.carseer.com/query?vin=$vin&lang=$lang";
        $response_create_report = $this->curlRequest($get_report_from_vin);
        $Total = $response_create_report['Products'][0]['Price'] + Yii::$app->params['carseer_report'];
        $data=[];
        $user = Users::findOne(['id' => Yii::$app->user->identity->id]);
        $name = $user->name;
        $phone = $user->phone;
        $email = $user->email;
        $APIKey = Yii::$app->params['payment']['api_key'];
        // $APIKey='TDGTG@45GHJRTJNCVSRSDFGD@@TERAF';
        $MerchantID = Yii::$app->params['payment']['merchant_id'];
        $ref = time();
        // $CurrencyCode = Yii::$app->params['payment']['currency_code'];
        $CurrencyCode= 'USD';
        $redirect_url = Yii::$app->urlManager->createAbsoluteUrl(['site/success-carseer-report-generated','id'=>$id,'vin'=>$vin]);

        curl_setopt_array($curl, array(
            CURLOPT_URL => Yii::$app->params['payment']['url'],
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => "{\"amount\":$Total,\"currency\":\"$CurrencyCode\",\"threeDSecure\":true,\"save_card\":false,\"description\":\"Test Description\",\"statement_descriptor\":\"Sample\",\"reference\":{\"transaction\":\"txn_{$ref}\",\"order\":\"ord_{$ref}\"},\"receipt\":{\"email\":true,\"sms\":false},\"customer\":{\"first_name\":\"$name\",\"email\":\"$email\",\"phone\":{\"country_code\":\"965\",\"number\":\"$phone\"}},\"merchant\":{\"id\":\"$MerchantID\"},\"source\":{\"id\":\"src_all\"},\"post\":{\"url\":\"$post_url\"},\"redirect\":{\"url\":\"$redirect_url\"}}",
            CURLOPT_HTTPHEADER => array(
                "authorization: Bearer $APIKey",
                "content-type: application/json"
            ),
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);

        curl_close($curl);


        if ($err) {
            echo "cURL Error #:" . $err;
        } else {
            $data = json_decode($response);
            // print_r( $data);die;
            return $this->redirect($data->transaction->url);

        }
        return $redirect_url;
    }

    public function actionImageUpload($id)
    {

        $path = __DIR__ . '/../web/uploads/car-listing';
        if(!is_dir($path)){
            FileHelper::createDirectory($path, $mode = 0777, $recursive = true);
        }
        $fast_sell_count = Vehicle::find()->where(['car_type' => Vehicle::FAST, 'user_id' => Yii::$app->user->identity->id ])->count();
        $vehicle = Vehicle::findOne(['id' => $id]);
        $model = new VehicleImages();
        // $equipment= VehicleEquipment::find()->where(['vehicle_id' => $id])->all();


        if ($model->load(Yii::$app->request->post())) {

            $model->path = UploadedFile::getInstances($model, 'path');

            $vehicle->save();

            if ($model->path && $model->validate(false)) {

                foreach ($model->path as $path) {
                    $filestring= Yii::$app->security->generateRandomString(12);
                    $upload = new VehicleImages();
                    $upload->vehicle_id = $id;
                    $upload->path = 'http://www.oto.jo/uploads/car-listing/'.$filestring;
                    $upload->extension = $path->extension;
                    $upload->type = VehicleImages::TYPE_ONE;
                    $upload->created_at = date('Y-m-d:H:i');
                    $upload->created_by = Yii::$app->user->identity->id;

                    if ($upload->save(false)) {

                        $path->saveAs('uploads/car-listing/' . $filestring.'.'. $path->extension);
                        $upload->removeCdnCache();
                    }
                }
                if ($fast_sell_count > Vehicle::COUNT_TWO) {

                    Yii::$app->session->setFlash('success',Yii::t('auto','You have to pay small amount to list as OtO Auction .'));
                    return $this->redirect(['pay','id' => $id ]);

                } elseif($vehicle->car_type == Vehicle::ROUND) {

                    Yii::$app->session->setFlash('success',Yii::t('auto','You have to pay some amount for OtO Elite .'));
                    return $this->redirect(Url::toRoute(['site/pay','id'=>$id]));

                } else {

                    Yii::$app->session->setFlash('success', Yii::t('auto','Car created successfully!'));
                    return $this->redirect(['confirm-car-detail','id' => $id]);

                }
            }
        }
        return $this->render('image-upload',[
            'model' => $model,
            'vehicle' => $vehicle,
        ]);
    }


    /**
     *  car detail page.
     *
     * @return mixed
     */
    public function actionConfirmCarDetail($id) {

        $model = Vehicle::findOne(['id' => $id]);

        if($this->request->get('tap_id')) {
            $APIKey = Yii::$app->params['payment']['api_key'];

            $curl = curl_init();
            curl_setopt_array($curl, array(
                CURLOPT_URL => "https://api.tap.company/v2/charges/".$this->request->get('tap_id'),
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => "",
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 30,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => "GET",
                CURLOPT_POSTFIELDS => "{}",
                CURLOPT_HTTPHEADER => array(
                    "authorization: Bearer $APIKey"
                ),
            ));

            $response = curl_exec($curl);
            $err = curl_error($curl);

            curl_close($curl);

            $response = json_decode($response);

            // print_r($response); die;
            if(isset($response->status) && $response->status == "CAPTURED") {
                // $model->approved_at = Vehicle::PUBLISHED;
                $model->status = Vehicle::ACTIVE;
                $model->sendEmailToNotifyPaymentSuccess();
                if($model->car_type == Vehicle::ROUND) {
                    Yii::$app->session->setFlash('success_vehicle', Yii::t('auto','Thanks for your time! We will contact you soon'));
                }
                // $model->save(false);
            } else {
                // $model->approved_at = Vehicle::NOT_PUBLISHED;
            }
            // if ($err) {
            //     echo "cURL Error #:" . $err;
            // } else {
            //     // echo $response;
            // }
        }

        // print_r($this->request->get('tap_id'));die;
        $drop_lang = new DropdownListLang();

        $user = Users::findOne(['id' => $model->user_id]);
        $image = VehicleImages::find()->where(['vehicle_id' => $id])->all();
        $attachment = VehicleImages::findOne(['vehicle_id' => $model->id,'type' => VehicleImages::TYPE_TWO])    ;

        $image_chunk = array_chunk($image,5);
        $equipment = VehicleEquipment::find()->where(['vehicle_id' => $id])->all();
        $remark = VehicleRemark::find()->where(['vehicle_id' => $id])->all();

        $model->save(false);



        return $this->render('confirm-car-detail',[
            'drop_lang' => $drop_lang,
            'model' => $model,
            'user' => $user,
            'image' => $image,
            'image_chunk' => $image_chunk,
            'equipment' => $equipment,
            'remark' => $remark,
            'attachment' => $attachment,
        ]);
    }

    public function actionPay($id)
    {
        $post_url = Yii::$app->urlManager->createAbsoluteUrl('/');
        $model = Vehicle::findOne(['id' => $id]);
        $curl = curl_init();
        $redirect_url = Yii::$app->urlManager->createAbsoluteUrl(['site/confirm-car-detail','id' => $model->id]);
        if ($model->car_type == Vehicle::FAST){
            $Total = Yii::$app->params['fast_sell_price'];
        }elseif ($model->car_type == Vehicle::ROUND) {
            $Total = Yii::$app->params['360_price'];
        }else{
            $Total = 0;
        }

        $user = Users::findOne(['id' => Yii::$app->user->identity->id]);
        $name = $user->name;
        $phone = $user->phone;
        $email = $user->email;
        $APIKey = Yii::$app->params['payment']['api_key'];
        $MerchantID = Yii::$app->params['payment']['merchant_id'];
        $ref = time();
        $CurrencyCode = Yii::$app->params['payment']['currency_code'];
        if($model->car_type == Vehicle::ROUND){
            $paymentDescription = "Booking payment for 360 Vehicle - oto.jo";
        }else if($model->car_type == Vehicle::FAST){
            $paymentDescription = "Auction Vehicle payment - oto.jo";
        }else{
            $paymentDescription = "Vehicle payment - oto.jo";
        }

        curl_setopt_array($curl, array(
            CURLOPT_URL => Yii::$app->params['payment']['url'],
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => "{\"amount\":$Total,\"currency\":\"$CurrencyCode\",\"threeDSecure\":true,\"save_card\":false,\"description\":\"{$paymentDescription}\",\"statement_descriptor\":\"Sample\",\"reference\":{\"transaction\":\"txn_{$ref}\",\"order\":\"ord_{$ref}\"},\"receipt\":{\"email\":true,\"sms\":false},\"customer\":{\"first_name\":\"$name\",\"email\":\"$email\",\"phone\":{\"country_code\":\"965\",\"number\":\"$phone\"}},\"merchant\":{\"id\":\"$MerchantID\"},\"source\":{\"id\":\"src_all\"},\"post\":{\"url\":\"$post_url\"},\"redirect\":{\"url\":\"$redirect_url\"}}",
            CURLOPT_HTTPHEADER => array(
                "authorization: Bearer $APIKey",
                "content-type: application/json"
            ),
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);

        curl_close($curl);


        if ($err) {
            echo "cURL Error #:" . $err;
        } else {
            $data = json_decode($response);
            return $this->redirect($data->transaction->url);
        }
        return $this->redirect('confirm-car-detail');
    }


    /* public function actionTestpay()
    {
        $post_url = Yii::$app->urlManager->createAbsoluteUrl('/');
        $model = Vehicle::findOne(24);
        $user = Users::findOne(13);
        $curl = curl_init();
        $redirect_url = Yii::$app->urlManager->createAbsoluteUrl(['site/confirm-car-detail','id'=>1]);

        $APIKey = Yii::$app->params['payment']['api_key'];
        $MerchantID = Yii::$app->params['payment']['merchant_id'];
        // $UserName = Yii::$app->params['payment']['username'];
        // $password = Yii::$app->params['payment']['password'];
        $ref = $model->id.time();
        $Mobile = $model->phone;
        $CurrencyCode = Yii::$app->params['payment']['currency_code'];


        if ($model->vehicle_type == Vehicle::FAST){

            $Total = Yii::$app->params['fast_sell_price'];

        }elseif ($model->vehicle_type == Vehicle::ROUND) {

            $Total = Yii::$app->params['360_price'];

        }else{
            $Total = 10;
        }

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => "https://api.tap.company/v2/charges",
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => "{\"amount\":$Total,\"currency\":\"$CurrencyCode\",\"threeDSecure\":true,\"save_card\":false,\"description\":\"Test Description\",\"statement_descriptor\":\"Sample\",\"reference\":{\"transaction\":\"txn_{$ref}\",\"order\":\"ord_{$ref}\"},\"receipt\":{\"email\":true,\"sms\":false},\"customer\":{\"first_name\":\"test\",\"middle_name\":\"test\",\"last_name\":\"test\",\"email\":\"test@test.com\",\"phone\":{\"country_code\":\"965\",\"number\":\"50000000\"}},\"merchant\":{\"id\":\"$MerchantID\"},\"source\":{\"id\":\"src_all\"},\"post\":{\"url\":\"$post_url\"},\"redirect\":{\"url\":\"$redirect_url\"}}",

            CURLOPT_HTTPHEADER => array(
                "authorization: Bearer sk_test_XKokBfNWv6FIYuTMg5sLPjhJ",
                "content-type: application/json"
            ),
        ));

        $response = curl_exec($curl);
        // print_r($response);die;
        $err = curl_error($curl);

        curl_close($curl);

        if ($err) {
            echo "cURL Error #:" . $err;
        } else {
            $data = json_decode($response);
            return $this->redirect($data->transaction->url);
        }
        return true;
    } */

    public function actionCardetail($slug)
    {
        $drop_lang = new DropdownListLang();
        $model = Vehicle::findOne(['slug' => $slug]);
        if (empty($model)) {
            throw new NotFoundHttpException(Yii::t('yii', 'Page not found.'));
        }
        $user = Users::findOne(['id' => $model->user_id]);

        $image = VehicleImages::find()->where(['vehicle_id' => $model->id,'type' => VehicleImages::TYPE_ONE])->all();
        $attachment = VehicleImages::findOne(['vehicle_id' => $model->id,'type' => VehicleImages::TYPE_TWO]);
        $image_chunk = array_chunk($image,5);
        $equipment = VehicleEquipment::find()->where(['vehicle_id' => $model->id])->all();
        $remark = VehicleRemark::find()->where(['vehicle_id' => $model->id])->all();


        $image360Data = [
            'imageUrlFormat' => '',
            'imagePath' => '',
            'imageFirstPlaceholder' => '',
            'totalFrames' => 0,
            'dragToRotateText' => Yii::t('auto', 'Drag To Rotate'),
            'dragToRotateTextForModal' => "<span class='swap-hint-text-lg'>".Yii::t('auto', 'Drag To Rotate')."</span>"."<span class='swap-hint-text-for-sm'>".Yii::t('auto', 'Swipe up & down to rotate')."</span>",
        ];
        if($model->car_type == Vehicle::ROUND){
            $firstImage = Images360::findOne(['vehicle_id'=>$model->id]);
            $count = Images360::find()->where(['vehicle_id'=>$model->id])->count();
            if(!empty($firstImage)){
                if(strpos($firstImage->path, '-webp-') !== false){
                    $pathInfo = pathinfo($firstImage->path);
                    $fileName=$pathInfo['filename'].".webp";
                    $image360Data['imageUrlFormat'] = preg_replace("/\([0-9]\)/", '(__x__)', $fileName);
                    $image360Data['imagePath'] = Yii::$app->params['adminUrl'].'/uploads/360images/webp/';
                }else{
                    //$image360Data['imageUrlFormat'] = preg_replace("/\([0-9]\)/", '(__x__)1100x550', $firstImage->path);
                    //$image360Data['imagePath'] = Yii::$app->params['adminUrl'].'/uploads/1100x550/';

                    $image360Data['imageUrlFormat'] = preg_replace("/\([0-9]\)/", '(__x__)', $firstImage->path);
                    //$image360Data['imagePath'] = Yii::$app->params['cdnUrl'].'/1100x550/uploads/360images/';
                    $image360Data['imagePath'] = Yii::$app->params['cdnUrl'].'/tr,w-'.Images360::CDN_CACHE_RESOLUTION['w'].',h-'.Images360::CDN_CACHE_RESOLUTION['h'].'/uploads/360images/';
                }

                $image360Data['imageFirstPlaceholder'] = preg_replace("/\(__x__\)/", '(1)', $image360Data['imageUrlFormat']);
                $image360Data['totalFrames'] = ($count > 360) ? 360 : $count;
            }
        }



        return $this->render('car-detail',[
            'drop_lang' => $drop_lang,
            'model' => $model,
            'user' => $user,
            'image' => $image,
            'image_chunk' => $image_chunk,
            'equipment' => $equipment,
            'remark' => $remark,
            'image360Data' => $image360Data,
            // 'userlogin'=>$userlogin,
            'attachment' =>$attachment

        ]);
    }

    public function actionLists($id)
    {
        $lang = \Yii::$app->language;
        $data =  \yii\helpers\ArrayHelper::map(Yii::$app->db->createCommand("SELECT DF.id, DS.title from dropdown_list DF, dropdown_list_lang DS WHERE DF.id = DS.parent_id and DF.parent_id = '$id' and DS.language = '$lang' ORDER BY 
                                                        CASE 
                                                            WHEN DS.title = 'Other'
                                                            THEN 1
                                                            ELSE 0
                                                        END ASC
                                                     , DS.title ASC  ")->queryAll(),'id','title');


         if (count($data)){
             echo "<option></option>";
            foreach ($data as $key=>$val){
                if(!empty($val)){
                    echo "<option value='".$key."'>".$val."</option>";
                }

            }
        }
        else{
            echo "<option></option>";
        }
    }

    public function actionFavourite()
    {
        $fav = \common\models\FavoriteVehicle::findOne(['id' => SORT_DESC]);

        if (Yii::$app->request->isAjax) {
            $data = Yii::$app->request->post();
            $model = \common\models\FavoriteVehicle::findOne(['user_id' => $data['user_id'], 'vehicle_id' => $data['vehicle_id']]);
            if ($model && $model->user_id == Yii::$app->user->identity->id && $model->vehicle_id == $data['vehicle_id']) {
                $model->delete();
            } else {
                $model = new \common\models\FavoriteVehicle();
                $model->user_id = $data['user_id'];
                $model->vehicle_id = $data['vehicle_id'];
                $model->created_at = date('Y-m-d H:i:s');
                $model->updated_at = date('Y-m-d H:i:s');
                $model->save(false);

                return true;
            }
        } else {
            return false;
        }

    }

    /**
     * Logs in a user.
     *
     * @return mixed
     */

    public function actionLogin()
    {
        if (!Yii::$app->user->isGuest) {
            return $this->goHome();
        }

        $model = new LoginFormF();
        if ($model->load(Yii::$app->request->post()) && $model->login()) {
            return $this->goBack();
        }

        if(Yii::$app->session->hasFlash('danger')){
            $model->addError('password', Yii::$app->session->getFlash('danger'));
            Yii::$app->session->removeFlash('danger');
        }

        $model->password = '';
        return $this->render('login', [
            'model' => $model,
        ]);
    }

    /**
     * Logs out the current user.
     *
     * @return mixed
     */
    public function actionLogout()
    {
        Yii::$app->user->logout();

        Yii::$app->session->setFlash('success',Yii::t('auto','Thank you for Choosing Us !'));

        return $this->goHome();
    }

    /**
     * Displays contact page.
     *
     * @return mixed
     */
    public function actionContact()
    {
        $model = new ContactForm();
        if ($model->load(Yii::$app->request->post())) {
            $contactFormdata=Yii::$app->request->post();
            $model->name= $contactFormdata['ContactForm']['username'];
            $model->email= $contactFormdata['ContactForm']['useremail'];
            $model->title= $contactFormdata['ContactForm']['subject'];
            $model->message= $contactFormdata['ContactForm']['body'];

            $model->save();

            if ($model->sendEmail(Yii::$app->params['adminEmail'])) {
                Yii::$app->session->setFlash('success', Yii::t('auto','Thank you for contacting us. We will respond to you as soon as possible.'));
            } else {
                Yii::$app->session->setFlash('error', Yii::t('auto','There was an error sending your message.'));
            }
            return $this->refresh();
        }

        return $this->render('contact', [
            'model' => $model,
        ]);
    }
    /**
     * Displays contact page.
     *
     * @return mixed
     */
    public function actionContactUs()
    {

        $model = new ContactForm();
        if ($model->load(Yii::$app->request->post())) {
            $contactFormdata=Yii::$app->request->post();
            $model->name= $contactFormdata['ContactForm']['username'];
            $model->email= $contactFormdata['ContactForm']['useremail'];
            $model->title= $contactFormdata['ContactForm']['subject'];
            $model->message= $contactFormdata['ContactForm']['body'];

            $model->save();
            if ($model->sendEmail(Yii::$app->params['adminEmail'])) {
                Yii::$app->session->setFlash('success', Yii::t('auto','Thank you for contacting us. We will respond to you as soon as possible.'));
            } else {
                Yii::$app->session->setFlash('error', Yii::t('auto','There was an error sending your message.'));
            }

            return $this->goHome(); //$this->refresh();

        }

        // return $this->render('index', [
        //     'model' => $model,
        // ]);
    }

    public function actionOwnerSignup()
    {
        $path = __DIR__ . '/../web/uploads/document';
        if(!is_dir($path)){
            FileHelper::createDirectory($path, $mode = 0777, $recursive = true);
        }
        $model = new SignupForm();
        $model->scenario = 'car_owner';
        if ($model->load(Yii::$app->request->post())) {
            $model->document = $image = UploadedFile::getInstance($model,'document');


            if($model->validate()){
                $user = new Users();
                $user->name = $model->name;
                $user->email = $model->email;
                $user->phone = $model->phone;
                $user->type = Users::OWNER;
                $user->is_document_approved = Users::REVIEW;
                $user->created_at = date('Y-m-d H:i:s');
                $user->email_verified_at = date('Y-m-d H:i:s');
                $user->setPassword($model->password);
                $user->generateAuthKey();
                $user->generateEmailVerificationToken();
                if ($user->save())
                {
                    if ($image){
                        $image->saveAs('uploads/document/'.$model->document);
                    }


                    /*
                     * Creating Owner of the user
                     * */

                    $ownerExists = Owner::findOne(['email' => $user->email]);
                    if(empty($ownerExists)){
                        $newOwner = new Owner();
                        $newOwner->name = 'Private Seller';
                        $newOwner->name_ar_ar = 'بائع خصوصي';
                        $newOwner->email = $user->email;
                        $newOwner->status = 1;
                        $newOwner->phone = $user->phone;
                        $newOwner->slug = 'private-seller-'.$user->id;
                        $newOwner->created_at = time();
                        $newOwner->updated_at = time();
                        if($newOwner->save()){
                            $user->owner_id = $newOwner->id;
                            $user->save(false);
                        }
                    }

                    Yii::$app->session->setFlash('success', Yii::t('auto','Thank you! You have successfully registered.'));
                    Yii::$app->user->login($user);
                    return $this->goHome();
                }else{
                    /*echo "<pre>";
                    print_r($user->errors);
                    die();*/
                }
            }
        }
        return $this->render('signup',[
            'model' => $model,
        ]);
    }

    /**
     * Signs user up.
     *
     * @return mixed
     * @throws \yii\base\Exception
     */

    public function actionDealerSignup()
    {
        $path = __DIR__ . '/../web/uploads/document';
        if(!is_dir($path)){
            FileHelper::createDirectory($path, $mode = 0777, $recursive = true);
        }
        $model = new SignupForm();
        $model->scenario = 'car_dealer';
        $user = new Users();
        if ($model->load(Yii::$app->request->post())) {
            $model->document = $image = UploadedFile::getInstance($model,'document');
            if($model->validate()){
                $user = new Users();
                $user->name = $model->name;
                $user->email = $model->email;
                $user->phone = $model->phone;
                $user->type = Users::DEALER;
                $user->created_at = date('Y-m-d H:i:s');
                $user->setPassword($model->password);
                $user->generateAuthKey();
                $user->generateEmailVerificationToken();
                if ($image) {
                    $model->document = Yii::$app->security->generateRandomString(12). '.'.$image->extension;
                    $user->document = $model->document;
                }
                if ($user->save())
                {
                    if ($image){
                        $image->saveAs('uploads/document/'.$model->document);
                    }

                    $ownerExists = Owner::findOne(['email' => $user->email]);
                    if(empty($ownerExists)){
                        $newOwner = new Owner();
                        $newOwner->name = 'Private Seller';
                        $newOwner->name_ar_ar = 'بائع خصوصي';
                        $newOwner->email = $user->email;
                        $newOwner->status = 1;
                        $newOwner->phone = $user->phone;
                        $newOwner->slug = 'private-seller-'.$user->id;
                        $newOwner->created_at = time();
                        $newOwner->updated_at = time();
                        if($newOwner->save()){
                            $user->owner_id = $newOwner->id;
                            $user->save(false);
                        }
                    }
                    //Yii::$app->session->setFlash('success', Yii::t('auto','Thank you! You have successfully registered.'));
                    Yii::$app->session->setFlash('success', Yii::t('auto','You have registered successfully! Waiting for our approval.'));
                    Yii::$app->user->login($user);
                    return $this->goHome();
                }else{
                    /*echo "<pre>";
                    print_r($user->errors);
                    die();*/
                }
            }
        }

        return $this->render('signup',[
            'model' => $model,
            'user' => $user,
        ]);
    }

    public function actionSignup()
    {
        if (!Yii::$app->user->isGuest) {
            return $this->goHome();
        }
        $modelOwnerForm = new SignupForm();
        $modelDealerForm = new DealersignupForm();


        if ($modelDealerForm->load(Yii::$app->request->post())) {
            // validate for ajax request
            if (Yii::$app->request->isAjax) {
                Yii::$app->response->format = Response::FORMAT_JSON;
                return ActiveForm::validate($modelDealerForm);
            }


            $modelDealerForm->document = $image = UploadedFile::getInstance($modelDealerForm,'document');
            if($modelDealerForm->validate()){
                $user = new Users();
                $user->name = $modelDealerForm->name;
                $user->email = $modelDealerForm->email;
                $user->source = Users::SOURCE_WEB;
                $user->phone = $modelDealerForm->phone;
                $user->type = Users::DEALER;
                $user->status = Users::STATUS_INACTIVE;
                $user->is_document_approved = Users::REVIEW;
                $user->created_at = date('Y-m-d H:i:s');
                $user->setPassword($modelDealerForm->password);
                $user->generateAuthKey();
                $user->generateEmailVerificationToken();
                if ($image) {
                    $modelDealerForm->document = Yii::$app->security->generateRandomString(12). '.'.$image->extension;
                    $user->document = '/uploads/document/'.$modelDealerForm->document;
                }
                if ($user->save())
                {
                    if ($image){
                        $image->saveAs('uploads/document/'.$modelDealerForm->document);
                    }

                    $ownerExists = Owner::findOne(['email' => $user->email]);
                    if(empty($ownerExists)){
                        $newOwner = new Owner();
                        $newOwner->name = 'Private Seller';
                        $newOwner->name_ar_ar = 'بائع خصوصي';
                        $newOwner->email = $user->email;
                        $newOwner->status = 1;
                        $newOwner->phone = $user->phone;
                        $newOwner->slug = 'private-seller-'.$user->id;
                        $newOwner->created_at = time();
                        $newOwner->updated_at = time();
                        if($newOwner->save()){
                            $user->owner_id = $newOwner->id;
                            $user->save(false);
                        }
                    }
                    $user->sendEmailToNotifyDealerRegistration();
                    Yii::$app->session->setFlash('success', Yii::t('auto','Thank you! You have successfully registered.'));
                    //Yii::$app->user->login($user);
                    return $this->goHome();
                }else{
                    echo "<pre>";print_r($user->getErrors());echo "</pre>";die('Call');
                }
            }
        }

        if ($modelOwnerForm->load(Yii::$app->request->post())) {
            // validate for ajax request
            if (Yii::$app->request->isAjax) {
                Yii::$app->response->format = Response::FORMAT_JSON;
                return ActiveForm::validate($modelOwnerForm);
            }

            if($modelOwnerForm->validate()){
                $user = new Users();
                $user->name = $modelOwnerForm->name;
                $user->email = $modelOwnerForm->email;
                $user->source = Users::SOURCE_WEB;
                $user->phone = $modelOwnerForm->phone;
                $user->type = Users::OWNER;
                $user->status = Users::STATUS_ACTIVE;
                $user->email_verified_at = date('Y-m-d H:i:s');
                $user->created_at = date('Y-m-d H:i:s');
                $user->setPassword($modelOwnerForm->password);
                $user->generateAuthKey();
                $user->generateEmailVerificationToken();
                if ($user->save())
                {
                    /*
                     * Creating Owner of the user
                     * */

                    $ownerExists = Owner::findOne(['email' => $user->email]);
                    if(empty($ownerExists)){
                        $newOwner = new Owner();
                        $newOwner->name = 'Private Seller';
                        $newOwner->name_ar_ar = 'بائع خصوصي';
                        $newOwner->email = $user->email;
                        $newOwner->status = 1;
                        $newOwner->phone = $user->phone;
                        $newOwner->slug = 'private-seller-'.$user->id;
                        $newOwner->created_at = time();
                        $newOwner->updated_at = time();
                        if($newOwner->save()){
                            $user->owner_id = $newOwner->id;
                            $user->save(false);
                        }
                    }

                    Yii::$app->session->setFlash('success', Yii::t('auto','Thank you! You have successfully registered.'));
                    Yii::$app->user->login($user);
                    return $this->goHome();
                }
            }
        }




        if(Yii::$app->session->hasFlash('danger')){
            $modelOwnerForm->addError('password', Yii::$app->session->getFlash('danger'));
            Yii::$app->session->removeFlash('danger');
        }
        if(Yii::$app->session->hasFlash('social_login_data')){
            $social_login_data = json_decode(Yii::$app->session->getFlash('social_login_data'), 1);
            $modelOwnerForm->name = (!empty($social_login_data['name'])) ? $social_login_data['name'] : '';
            $modelOwnerForm->email = (!empty($social_login_data['name'])) ? $social_login_data['email'] : '';
            Yii::$app->session->removeFlash('social_login_data');
        }

        return $this->render('signup',[
            'modelOwnerForm' => $modelOwnerForm,
            'modelDealerForm' => $modelDealerForm,
        ]);
    }

    public function actionBecomeDealer()
    {
        $model = User::findOne(['id' => Yii::$app->user->identity->id]);

        if ($model->load(Yii::$app->request->post())) {
            $document = UploadedFile::getInstance($model,'document');
            $model->type = User::DEALER;
            if ($document) {
                $model->document = Yii::$app->security->generateRandomString(12).'.'.$document->extension;
            }
            if ($model->save()) {

                if ($document) {
                    $document->saveAs('uploads/document/'.$model->document);
                }
                Yii::$app->session->setFlash('success',Yii::t('auto','Your Document verification is pending !'));
                return $this->redirect('index');
            }
            Yii::$app->session->setFlash('danger',Yii::t('auto','Something went wrong please try again later !'));
        }
        return $this->render('become-dealer',[
            'model' => $model
        ]);
    }
    /*
    Chatbox Page
    */
    public function actionChatboxmessage($id)
    {

        if(!Yii::$app->user->isGuest){

            if(MessageFrom::findOne(['id' => $id])){
                $getvehicleid=MessageFrom::findOne(['id' => $id]);
                $vehicle=Vehicle::findOne(['id' => $getvehicleid->vehicle_id]);
        $model =  Users::findOne(['id' => Yii::$app->user->identity->id]);
        return $this->render('user-dashboard/chatboxmessage',[
            'model' => $model,
            'groupid'=>$id,
            'vehicle'=>$vehicle
        ]);
        }else{
        return $this->goHome();
        }
       }else{
        return $this->goHome();
       }

    }
    public function actionChatbox()
    {
        if(!Yii::$app->user->isGuest){
            $model = Users::findOne(['id' => Yii::$app->user->identity->id]);
            $groupid=  MessageFrom::find()->where(['owner_id'=> Yii::$app->user->identity->id])->andWhere(['!=', 'message_id', 'Null'])->orderBy(['message_id' => SORT_DESC])->all();
           if( $groupid){
            foreach( $groupid as $value){
                // $messageid=GroupmessageFrom::findOne(['id' => $value->message_id]);
                // if($messageid){
                //     $value->message_id= $messageid->message;
                //     $value->created_at =date('d-M-Y',$messageid->created_at);
                //     }
            }
           }else{
            $groupid = MessageFrom::find()->where(['user_id'=> Yii::$app->user->identity->id])->andWhere(['!=', 'message_id', 'Null'])->orderBy(['message_id' => SORT_DESC])->all();
            foreach( $groupid as $value){
                // $messageid=GroupmessageFrom::findOne(['id' => $value->message_id]);
                // if($messageid){
                // $value->message_id= $messageid->message;
                // $value->created_at =date('d-M-Y',$messageid->created_at);
                // }
            }
            }
            return $this->render('user-dashboard/chatbox',[
                'model' => $model,
                'Allchat'=> $groupid

            ]);

        }else{
            return $this->goHome();
        }
    }
    public function actionMessage($id)
    {

        if(!Yii::$app->user->isGuest){
        $model =  Users::findOne(['id' => Yii::$app->user->identity->id]);
        $vehicle=Vehicle::findOne(['id' => $id]);
        $dataProvider = new ActiveDataProvider([
            'query' => Vehicle::find()->where(['user_id' => $model->id]),
        ]);
        $messagedata= new MessageFrom();
        if(!MessageFrom::findOne(['user_id' => $model->id,'vehicle_id' =>$id,'owner_id' =>$vehicle->user_id])){
            $messagedata->user_id=$model->id;
            $messagedata->owner_id=$vehicle->user_id;
            $messagedata->vehicle_id=$vehicle->id;
            $messagedata->created_at=time();
            $messagedata->updated_at=time();
            $messagedata->save();
        }else{
            $messagedata=MessageFrom::findOne(["user_id"=>$model->id,"owner_id"=>$vehicle->user_id,"vehicle_id"=>$vehicle->id]);
        }
        $groupmessagedata=GroupmessageFrom::findAll(["group_id"=>$messagedata->id]);
        return $this->render('message',[
            'model' => $model,
            'dataProvider' => $dataProvider,
            'vehicle'=>$vehicle,
            'groupid'=>$messagedata->id,
            'groupmessagedata'=> $groupmessagedata,
        ]);
    }else{
        return $this->goHome();
    }

    }
    public function actionLoadmessagedata(){
        if(Yii::$app->request->isAjax && Yii::$app->request->get() ){
            $gid= $_GET['groupid'];
        $groupmessagedata=GroupmessageFrom::findAll(["group_id"=>$gid]);
        foreach($groupmessagedata as $value){

            if($value->user_id != Yii::$app->user->identity->id){
                $model =GroupmessageFrom::findAll(['group_id'=>$gid,'user_id'=>$value->user_id,'status'=>0]);
                foreach( $model as $models){
                $models->status = 1;
                $models->save();
                }
            }
            $value->created_at=date('d-M-Y ',$value->created_at);
        }

        // print_r(date('Y-m-d H:i:s',$value->created_at));die;
        }
        Yii::$app->response->format = 'json';
        return $groupmessagedata;
       }


    public function actionSendmessage(){
        if(Yii::$app->request->isAjax && Yii::$app->request->get()){
           $id= $_GET['groupid'];
           $model =  Users::findOne(['id' => Yii::$app->user->identity->id]);
           $message= $_GET['message'];
           if($message){
           $groupmsg= new GroupmessageFrom();
           $groupmsg->group_id=$id;
           $groupmsg->user_id=$model->id;
           $groupmsg->message=$message;
           $groupmsg->status=GroupmessageFrom::unread;
           $groupmsg->created_at=time();
            $groupmsg->updated_at=time();
           $groupmsg->save();
          $updatemessageid= MessageFrom::findOne(['id' =>$id]);
          $updatemessageid->message_id=$groupmsg->id;
          $updatemessageid->save();
           }
           Yii::$app->response->format = 'json';
           return $id;
         }

    }
    /**
     *  profile page.
     *
     * @return mixed
     */
    public function actionProfile()
    {
        $model = Users::findOne(['id' => Yii::$app->user->identity->id]);
        $changePasswordForm = new ChangePasswordForm();
        return $this->render('profile',[
            'model' => $model,
            'changePasswordForm' => $changePasswordForm,
        ]);
    }

    public function actionNotifications(){
        if(Yii::$app->user->isGuest){
            return $this->goHome();
        }
        $notificationsList = Notifications::find()->where(['owner_id' => Yii::$app->user->identity->owner_id])->orderBy('id desc')->all();
        Notifications::updateAll(['is_read' => 1], ['is_read' => 0, 'owner_id' => Yii::$app->user->identity->owner_id]);
        return $this->render('user-dashboard/notifications',[
            'notificationsList' => $notificationsList
        ]);
    }

    public function actionChangePassword(){

        $model= Users::findOne(Yii::$app->user->identity->id);
        $changePasswordForm = new ChangePasswordForm();

        if ($changePasswordForm->load(Yii::$app->request->post())){
            if($changePasswordForm->validate()){
                $model->setPassword($changePasswordForm->new_password);
                if ($model->save(false)){
                    Yii::$app->session->setFlash('success',Yii::t('auto','Password has been changed successfully'));
                    return $this->redirect(['profile']);
                }
            }else{
                $error = $changePasswordForm->getFirstErrors()[array_keys($changePasswordForm->getFirstErrors())[0]];
                //Yii::$app->session->setFlash('error', Yii::t('auto',$error));
            }

        }
        return $this->render('profile',[
            'model'=>$model,
            'active'=>'change-password',
            'changePasswordForm' => $changePasswordForm,
        ]);
    }

    /**
     * Requests password reset.
     *
     * @return mixed
     */
    public function actionRequestPasswordReset()
    {
        $model = new PasswordResetRequestForm();
        if ($model->load(Yii::$app->request->post()) && $model->validate()) {
            if ($model->sendEmail()) {
                Yii::$app->session->setFlash('success', Yii::t('auto','Check your email for further instructions.'));

                return $this->goHome();
            }

            Yii::$app->session->setFlash('error', Yii::t('auto','Sorry, we are unable to reset password for the provided email address.'));
        }

        return $this->render('requestPasswordResetToken', [
            'model' => $model,
        ]);
    }

    /**
     * Resets password.
     *
     * @param string $token
     * @return mixed
     * @throws BadRequestHttpException
     */
    public function actionResetPassword($token)
    {
        try {
            $model = new ResetPasswordForm($token);
        } catch (InvalidArgumentException $e) {
            throw new BadRequestHttpException($e->getMessage());
        }

        if ($model->load(Yii::$app->request->post()) && $model->validate() && $model->resetPassword()) {
            Yii::$app->session->setFlash('success', Yii::t('auto','New password saved.'));

            return $this->goHome();
        }

        return $this->render('resetPassword', [
            'model' => $model,
        ]);
    }

    /**
     * Verify email address
     *
     * @param string $token
     * @throws BadRequestHttpException
     * @return yii\web\Response
     */
    public function actionVerifyEmail($token)
    {
        try {
            $model = new VerifyEmailForm($token);
        } catch (InvalidArgumentException $e) {
            throw new BadRequestHttpException($e->getMessage());
        }
        if (($user = $model->verifyEmail()) && Yii::$app->user->login($user)) {
            Yii::$app->session->setFlash('success', Yii::t('auto','Your email has been confirmed!'));
            return $this->goHome();
        }

        Yii::$app->session->setFlash('error', Yii::t('auto','Sorry, we are unable to verify your account with provided token.'));
        return $this->goHome();
    }

    /**
     * Resend verification email
     *
     * @return mixed
     */
    public function actionResendVerificationEmail()
    {
        $model = new ResendVerificationEmailForm();
        if ($model->load(Yii::$app->request->post()) && $model->validate()) {
            if ($model->sendEmail()) {
                Yii::$app->session->setFlash('success', Yii::t('auto','Check your email for further instructions.'));
                return $this->goHome();
            }
            Yii::$app->session->setFlash('error', Yii::t('auto','Sorry, we are unable to resend verification email for the provided email address.'));
        }

        return $this->render('resendVerificationEmail', [
            'model' => $model
        ]);
    }

    /**
     * @param $id
     *
     * @return \common\models\User|void|null
     * @throws \yii\web\NotFoundHttpException
     */
    public function findUser($id)
    {
        if (($id = Users::findOne(['id' => $id])) !== null) {
            return $id;

            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }

    /**
     * @param $id
     * @return string
     */
    public function actionDealerProfile($id)
    {
        $model = Users::findOne(['id' => $id]);
        $dataProvider = new ActiveDataProvider([
            'query' => Vehicle::find()->where(['user_id' => $model->id]),
        ]);

        return $this->render('dealer-profile',[
            'model' => $model,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     *  car auction detail page.
     *
     * @return mixed
     */
    public function actionBid($slug)
    {
        $model = Vehicle::findOne(['user_id' => Yii::$app->user->identity->id, 'slug' => $slug]);
        $dataProvider = new ActiveDataProvider([
            'query' => VehicleBids::find(),
        ]);
        $dataProvider->query->where(['vehicle_id' => $model->id]);

        return $this->render('bid', [
            'model' => $model,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * @param $id
     *
     * @return string|\yii\web\Response
     */
    public function actionBids($id)
    {
        $check_user_bid_on_vehicle = VehicleBids::findOne(['vehicle_id' => $id, 'user_id' => Yii::$app->user->identity->id]);
        $vehicle = Vehicle::findOne(['id' => $id, 'user_id' => Yii::$app->user->identity->id]);
        $vehicleDetails = Vehicle::findOne(['id' => $id]);

        $user = Users::findOne(['id' => Yii::$app->user->identity->id, 'type' => User::DEALER]);
        if ($user == false){
            return $this->renderAjax('bid-error',[
                'message' => Yii::t('auto','This option is only for Registered Dealers.'),
            ]);
            /*Yii::$app->session->setFlash('danger',Yii::t('auto','Your have to be as dealer to bid'));
            return $this->goHome();*/
        }

        if($vehicleDetails->car_type == Vehicle::FAST && $vehicleDetails->isAuctionExpired()){
            return $this->renderAjax('bid-error',[
                'message' => Yii::t('auto','Auction is expired for this vehicle'),
            ]);
            /*Yii::$app->session->setFlash('danger',Yii::t('auto','Auction is expired for this vehicle'));
            return $this->goHome();*/
        }



        if ($vehicle == true) {
            return $this->renderAjax('bid-error',[
                'message' => Yii::t('auto','You are not allowed to bid on your own listing!'),
            ]);
            /*Yii::$app->session->setFlash('danger',Yii::t('auto','You are not allow to bid on your own Listing !'));
            return $this->goHome();*/
        }

        if ($check_user_bid_on_vehicle == true) {
            return $this->renderAjax('bid-error',[
                'message' => Yii::t('auto','You have already bid on this car!'),
            ]);
            /*Yii::$app->session->setFlash('danger',Yii::t('auto','You already bid on this Listing'));
            return $this->goHome();*/
        }

        $model = new VehicleBids();
        $user = Users::findOne(['id' => $vehicleDetails->user_id]);

        $show_bid = VehicleBids::find()->where(['vehicle_id' => $id])->all();
        $min_value = VehicleBids::find()->where(['vehicle_id' => $id])->max('bid');
        if ($model->load(Yii::$app->request->post())) {

            $model->vehicle_id = $id;
            $model->user_id = Yii::$app->user->identity->id;
            $model->created_at = date('Y-m-d H:i:s');
            $model->updated_at = date('Y-m-d H:i:s');
            $model->created_by = Yii::$app->user->identity->id;

            if ($model->save(false)) {

                /*
                 * Bid Notification
                 * */
                NotificationsHelper::sendAndSaveNotification('bid_placed', $model);

                /*
                 * Email Notification
                 * */
                $model->sendEmail($user->email, $user, $vehicleDetails);
                Yii::$app->session->setFlash('success', Yii::t('auto','Bid send successfully'));
                return $this->goHome();
            } else {
                Yii::$app->session->setFlash('danger', Yii::t('auto','Something Went wrong please try again Later !'));
            }
        }

        return $this->renderAjax('bid-form',[
            'model' => $model,
            'show_bid' => $show_bid,
            'min_value' => $min_value,
        ]);
    }

    /**
     * @param int $id ID
     * @return mixed
     * @throws NotFoundHttpException
     */
    public function actionDelete($id)
    {
        $this->findVehicleModel($id)->delete();

        Yii::$app->session->setFlash('success', Yii::t('auto','You Listing is Deleted Successfully !'));
        return $this->redirect(['my-listing']);
    }

    /**
     * @return string
     */
    public function actionBidForm()
    {
        $model = new VehicleBids();
        return $this->render('bid-form',[
            'model' => $model
        ]);
    }

    public function actionValidation()
    {
        $model = new VehicleBids();

        if (Yii::$app->request->isAjax && $model->load(Yii::$app->request->post()))
        {
            Yii::$app->response->format = 'json';
            return ActiveForm::validate($model);
        }
        return true;
    }

    /**
     * Finds the VehicleBids model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param int $id ID
     * @return Vehicle the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function findVehicleModel($id)
    {
        if (($model = Vehicle::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page not exit. ');
    }

    /**
     * @param $api_url
     *
     * @return mixed|string
     */
    public function curlRequest($api_url)
    {
        $api_key = "TDGTG@45GHJRTJNCVSRSDFGD@@TERAF";

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => $api_url."&key=".$api_key,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "GET"
        ));

        $response = curl_exec($curl);
        $err = curl_error($curl);

        curl_close($curl);

        if ($err) {
            return "cURL Error #:" . $err;
        }

        return json_decode($response, true);
    }

    public function actionNewsLetter(){

        $model = new NewsletterClientList();
        $newsletter = new DynamicModel(['email']);
        $newsletter->addRule(['email'], 'required');
        $newsletter->addRule(['email'], 'email');
        if ($newsletter->load(Yii::$app->request->post())) {
            $model->email = $newsletter->email;
            $model->created_at = time();
            if ($model->save(false)) {
                Yii::$app->session->setFlash('success',Yii::t('auto', 'You are now subscribed!'));
                return $this->goBack();
            }

        }
    }

    public function oAuthSuccess($client)
    {
        try {
            $userAttributes = $client->getUserAttributes();


            /*echo "<pre>";print_r(Yii::$app->request->get());echo "</pre>";
            echo "<pre>";print_r(Yii::$app->request->post());echo "</pre>";
            echo "<pre>";print_r($userAttributes);echo "</pre>";
            echo "<pre>";print_r($client);echo "</pre>";
            die('Call');*/

            $userEmail= $userAttributes['email'];
            $userFullName = $userAttributes['name'];
            $userSocialId  = $userAttributes['id'];
            $user = Users::findOne([
                "email" => $userEmail
            ]);

            switch (Yii::$app->request->get('task')){
                case 'login':
                    if (empty($user)) {

                        Yii::$app->session->setFlash('social_login_data', json_encode([
                            'name' => $userFullName,
                            'email' => $userEmail,
                        ]));
                        throw new \Exception("Your email is not registered with us. Please sign up first or click on Sign Up with GoogleG or Facebook", 101);
                    }

                    Yii::$app->user->login($user);
                    return $this->redirect('/');
                    break;
                case 'signup':
                    if (empty($user)) {
                        $user = new Users();
                        $user->name = $userFullName;
                        $user->email = $userEmail;
                        $user->source = (in_array(Yii::$app->request->get('authclient'), [Users::SOURCE_FACEBOOK, Users::SOURCE_GOOLE])) ? Yii::$app->request->get('authclient') : Users::SOURCE_WEB;
                        $user->phone = null;
                        $user->type = Users::OWNER;
                        $user->status = Users::STATUS_ACTIVE;
                        $user->email_verified_at = date('Y-m-d H:i:s');
                        $user->created_at = date('Y-m-d H:i:s');
                        //$user->setPassword(Yii::$app->security->generateRandomString(8));
                        $user->generateAuthKey();
                        $user->generateEmailVerificationToken();
                        $user->save(false);

                        /*
                        * Creating Owner of the user
                        * */

                        $ownerExists = Owner::findOne(['email' => $user->email]);
                        if(empty($ownerExists)){
                            $newOwner = new Owner();
                            $newOwner->name = 'Private Seller';
                            $newOwner->name_ar_ar = 'بائع خصوصي';
                            $newOwner->email = $user->email;
                            $newOwner->status = 1;
                            $newOwner->phone = $user->phone;
                            $newOwner->slug = 'private-seller-'.$user->id;
                            $newOwner->created_at = time();
                            $newOwner->updated_at = time();
                            if($newOwner->save()){
                                $user->owner_id = $newOwner->id;
                                $user->save(false);
                            }
                        }

                        Yii::$app->session->setFlash('success', Yii::t('auto','Thank you! You have successfully registered.'));
                    }
                    Yii::$app->user->login($user);
                    return $this->redirect('/');
                    break;
                default:
                    throw new \Exception("Invalid request. An error occurred while validating your request. Please try again");
            }
        }catch (\Exception $e){

            $message = ($e->getCode() == 101) ? $e->getMessage() : Yii::t('auto', 'An error occurred while processing your request. Please try again');


            switch (Yii::$app->request->get('task')){
                case 'login':
                case 'signup':
                    $dangerKey = 'danger-social';
                    $redirectionUrl = '/site/signup';
                    break;
                default:
                    $dangerKey = 'danger-social';
                    $redirectionUrl = '/';
            }
            Yii::$app->session->setFlash($dangerKey, $message);
            return $this->redirect($redirectionUrl);
        }
    }
}
