<?php

namespace frontend\models;

use common\models\Role;
use Yii;
use yii\base\Model;
use common\models\User;
use yii\web\UploadedFile;

/**
 * Signup form
 */
class SignupForm extends Model
{
    public $username;
    public $email;
    public $password;
    public $name;
    public $document;
    public $phone;

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            ['username', 'safe'],
            ['email', 'email', 'message' => Yii::t('auto', 'Email is not a valid email address.')],
            ['email', 'string', 'max' => 255],
            ['email', 'unique', 'targetClass' => '\common\models\Users', 'message' => Yii::t('auto', 'This email address has already been taken.')],
            ['document','safe'],
            [['document'], 'file', 'skipOnEmpty' => true, 'extensions' => 'jpg, jpeg, doc, docx, pdf'],
            [['email','password','name',  'phone'],'required'],
            [['phone'],'number'],
            ['password', 'string', 'min' => Yii::$app->params['user.passwordMinLength'], 'tooShort' => Yii::t('auto', 'Password should contain at least {min} characters.')],
            ['password', 'match',
                //'pattern' => '/^(?=.*[0-9])(?=.*[A-Z])([a-zA-Z0-9]+)$/',
                'pattern' => '/^(?=.*[A-Za-z])(?=.*\d)(?=.*[_@$!%*#?&])[A-Za-z\d_@$!%*#?&]{6,}$/',
                'message' => Yii::t('auto','Password must have minimum six characters, at least one letter, one number and one special character'),
            ],
        ];
    }

    /**
     * Signs user up.
     *
     * @return bool whether the creating new account was successful and email was sent
     */
    public function signup()
    {
        if (!$this->validate()) {

            $user = new User();
            $user->username = $this->username;
            $user->email = $this->email;
            $user->name = $this->name;
            $user->setPassword($this->password);
            $user->generateAuthKey();
            $user->generateEmailVerificationToken();
            
            if ($user->save()) {
                $auth = Yii::$app->authManager;
                $Role = $auth->getRole(Role::TYPE_ROLE_KEY['car_owner']);
                $auth->assign($Role, $user->primaryKey);
                $this->sendEmail($user);
            }
        }
        return false;
    }
    /**
     * Sends confirmation email to user
     * @param User $user user model to with email should be send
     * @return bool whether the email was sent
     */
    public function sendEmail($user)
    {
        return Yii::$app
            ->mailer
            ->compose(
                ['html' => 'emailVerify-html', 'text' => 'emailVerify-text'],
                ['user' => $user]
            )
            ->setFrom([Yii::$app->params['supportEmail'] => Yii::$app->name . ' robot'])
            ->setTo($this->email)
            ->setSubject('Account registration at ' . Yii::$app->name)
            ->send();
    }
}
